# This file was auto-generated by Fern from our API Definition.

import typing

from ....core.api_error import ApiError
from ..types.updates_disabled_due_to_external_system_integration_error_message import (
    UpdatesDisabledDueToExternalSystemIntegrationErrorMessage,
)


class UpdatesDisabledDueToExternalSystemIntegrationError(ApiError):
    def __init__(
        self,
        body: UpdatesDisabledDueToExternalSystemIntegrationErrorMessage,
        headers: typing.Optional[typing.Dict[str, str]] = None,
    ):
        super().__init__(status_code=422, headers=headers, body=body)
