# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class UserConfiguredPromptsResult(UniversalBaseModel):
    """
    Individual result from a single user-configured prompt execution
    """

    user_prompt_id: str = pydantic.Field()
    """
    Reference to the user prompt in eligibility config
    """

    prompt_name: str = pydantic.Field()
    """
    User-defined name for the prompt
    """

    structured_response: typing.Any = pydantic.Field()
    """
    The AI's structured answer (boolean, number, or string)
    """

    exposition: str = pydantic.Field()
    """
    The AI's explanation of the answer
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
