# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....appointments.resources.v_1.types.appointment import Appointment
from .....appointments.resources.v_1.types.universal_service_identifier import UniversalServiceIdentifier
from .....coverages.resources.v_1.types.mutable_coverage import MutableCoverage
from .....patients.resources.v_1.types.mutable_patient_with_mrn import MutablePatientWithMrn


class AppointmentListItem(UniversalBaseModel):
    appointment: Appointment
    patient: MutablePatientWithMrn
    primary_coverage: typing.Optional[MutableCoverage] = None
    secondary_coverage: typing.Optional[MutableCoverage] = None
    primary_service_type: typing.Optional[UniversalServiceIdentifier] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
