# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .health_care_code_information import HealthCareCodeInformation
from .occurrence_span_code import OccurrenceSpanCode
from .occurrence_span_code_qualifier import OccurrenceSpanCodeQualifier
from .rd_8_date import Rd8Date


class OccurrenceSpanInformation(HealthCareCodeInformation):
    """
    This corresponds to the BI code qualifier value.
    """

    occurrence_span_code_qualifier: OccurrenceSpanCodeQualifier
    occurrence_span_code: OccurrenceSpanCode
    occurrence_span_date: Rd8Date

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
