# This file was auto-generated by Fern from our API Definition.

import typing

from ......core.api_error import ApiError
from ..types.encounter_rendering_or_attending_provider_required_error import (
    EncounterRenderingOrAttendingProviderRequiredError,
)


class EncounterRenderingOrAttendingProviderRequired(ApiError):
    def __init__(
        self,
        body: EncounterRenderingOrAttendingProviderRequiredError,
        headers: typing.Optional[typing.Dict[str, str]] = None,
    ):
        super().__init__(status_code=422, headers=headers, body=body)
