# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .....commons.types.email import Email
from .....commons.types.phone_number import PhoneNumber
from .guarantor_base import GuarantorBase


class GuarantorCreate(GuarantorBase):
    phone_numbers: typing.Optional[typing.List[PhoneNumber]] = None
    phone_consent: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Defaults to false
    """

    email: typing.Optional[Email] = None
    email_consent: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Defaults to false
    """

    auto_charge_consent: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Defaults to false
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
