# This file was auto-generated by Fern from our API Definition.

import typing

from ........core import enum

T_Result = typing.TypeVar("T_Result")


class VoteValue(enum.StrEnum):
    """
    Possible vote values for recommendation quality
    """

    UPVOTE = "UPVOTE"
    DOWNVOTE = "DOWNVOTE"
    _UNKNOWN = "__VOTEVALUE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "VoteValue":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        upvote: typing.Callable[[], T_Result],
        downvote: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is VoteValue.UPVOTE:
            return upvote()
        if self is VoteValue.DOWNVOTE:
            return downvote()
        return _unknown_member(self._value_)
