# This file was auto-generated by Fern from our API Definition.

import typing
import uuid

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ContractServiceFacilityBase(UniversalBaseModel):
    service_facility_id: uuid.UUID = pydantic.Field()
    """
    The UUID of the service facility
    """

    provider_ids: typing.Set[uuid.UUID] = pydantic.Field()
    """
    The providers who are authorized under the contract
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
