# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .identifier import Identifier
    from .identifier_base import IdentifierBase
    from .identifier_code import IdentifierCode
    from .identifier_create import IdentifierCreate
    from .identifier_id import IdentifierId
    from .identifier_update import IdentifierUpdate
    from .identifier_value import (
        IdentifierValue,
        IdentifierValue_MedicaidProviderIdentifier,
        IdentifierValue_MedicareProviderIdentifier,
    )
    from .medicaid_provider_identifier import MedicaidProviderIdentifier
    from .medicare_provider_identifier import MedicareProviderIdentifier
    from .updatable_identifier import (
        UpdatableIdentifier,
        UpdatableIdentifier_Add,
        UpdatableIdentifier_Remove,
        UpdatableIdentifier_Update,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "Identifier": ".identifier",
    "IdentifierBase": ".identifier_base",
    "IdentifierCode": ".identifier_code",
    "IdentifierCreate": ".identifier_create",
    "IdentifierId": ".identifier_id",
    "IdentifierUpdate": ".identifier_update",
    "IdentifierValue": ".identifier_value",
    "IdentifierValue_MedicaidProviderIdentifier": ".identifier_value",
    "IdentifierValue_MedicareProviderIdentifier": ".identifier_value",
    "MedicaidProviderIdentifier": ".medicaid_provider_identifier",
    "MedicareProviderIdentifier": ".medicare_provider_identifier",
    "UpdatableIdentifier": ".updatable_identifier",
    "UpdatableIdentifier_Add": ".updatable_identifier",
    "UpdatableIdentifier_Remove": ".updatable_identifier",
    "UpdatableIdentifier_Update": ".updatable_identifier",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "Identifier",
    "IdentifierBase",
    "IdentifierCode",
    "IdentifierCreate",
    "IdentifierId",
    "IdentifierUpdate",
    "IdentifierValue",
    "IdentifierValue_MedicaidProviderIdentifier",
    "IdentifierValue_MedicareProviderIdentifier",
    "MedicaidProviderIdentifier",
    "MedicareProviderIdentifier",
    "UpdatableIdentifier",
    "UpdatableIdentifier_Add",
    "UpdatableIdentifier_Remove",
    "UpdatableIdentifier_Update",
]
