# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class PrincipalDiagnosisCodeQualifier(enum.StrEnum):
    CBK = "BK"
    """
    International Classification of Diseases Clinical Modification (ICD-9-CM) Principal Diagnosis
    """

    CABK = "ABK"
    """
    International Classification of Diseases Clinical Modification (ICD-10-CM) Principal Diagnosis
    """

    _UNKNOWN = "__PRINCIPALDIAGNOSISCODEQUALIFIER_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "PrincipalDiagnosisCodeQualifier":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        cbk: typing.Callable[[], T_Result],
        cabk: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is PrincipalDiagnosisCodeQualifier.CBK:
            return cbk()
        if self is PrincipalDiagnosisCodeQualifier.CABK:
            return cabk()
        return _unknown_member(self._value_)
