# This file was auto-generated by Fern from our API Definition.

import typing

from ........core import enum

T_Result = typing.TypeVar("T_Result")


class EligibilityStatus(enum.StrEnum):
    """
    enum to represent the status of a patient's coverage
    """

    ACTIVE = "ACTIVE"
    INACTIVE = "INACTIVE"
    UNKNOWN = "UNKNOWN"
    _UNKNOWN = "__ELIGIBILITYSTATUS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "EligibilityStatus":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        active: typing.Callable[[], T_Result],
        inactive: typing.Callable[[], T_Result],
        unknown: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is EligibilityStatus.ACTIVE:
            return active()
        if self is EligibilityStatus.INACTIVE:
            return inactive()
        if self is EligibilityStatus.UNKNOWN:
            return unknown()
        return _unknown_member(self._value_)
