# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....common.types.user_id import UserId
from .vote_value import VoteValue


class Vote(UniversalBaseModel):
    """
    User feedback on a recommendation
    """

    user_id: UserId = pydantic.Field()
    """
    The user who voted
    """

    value: VoteValue = pydantic.Field()
    """
    The vote value
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
