# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....eligibility_checks.resources.v_1.types.eligibility_status import EligibilityStatus


class LatestEligibilityCheck(UniversalBaseModel):
    """
    A type to represent the latest eligibility check status of a coverage.
    """

    check_id: str
    status: EligibilityStatus
    initiated_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
