# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class PrincipalProcedureInformationCodeQualifier(enum.StrEnum):
    CBBR = "BBR"
    """
    International Classification of Diseases Clinical Modification (ICD-10-PCS) Principal Procedure Codes
    """

    CBR = "BR"
    """
    International Classification of Diseases Clinical Modification (ICD-9-CM) Principal Procedure Codes
    """

    CCAH = "CAH"
    """
    Advanced Billing Concepts (ABC) Codes
    """

    _UNKNOWN = "__PRINCIPALPROCEDUREINFORMATIONCODEQUALIFIER_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "PrincipalProcedureInformationCodeQualifier":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        cbbr: typing.Callable[[], T_Result],
        cbr: typing.Callable[[], T_Result],
        ccah: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is PrincipalProcedureInformationCodeQualifier.CBBR:
            return cbbr()
        if self is PrincipalProcedureInformationCodeQualifier.CBR:
            return cbr()
        if self is PrincipalProcedureInformationCodeQualifier.CCAH:
            return ccah()
        return _unknown_member(self._value_)
