# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class EmploymentStatus(enum.StrEnum):
    ACTIVE = "ACTIVE"
    TERMINATED = "TERMINATED"
    _UNKNOWN = "__EMPLOYMENTSTATUS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "EmploymentStatus":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        active: typing.Callable[[], T_Result],
        terminated: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is EmploymentStatus.ACTIVE:
            return active()
        if self is EmploymentStatus.TERMINATED:
            return terminated()
        return _unknown_member(self._value_)
