# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.user_id import UserId
from ...commons.types.task_status import TaskStatus


class TaskUpdateV3(UniversalBaseModel):
    status: typing.Optional[TaskStatus] = None
    assignee_user_id: typing.Optional[UserId] = None
    blocks_claim_submission: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
