# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .create_non_insurance_payer_request import CreateNonInsurancePayerRequest
    from .non_insurance_payer import NonInsurancePayer
    from .non_insurance_payer_address_update import (
        NonInsurancePayerAddressUpdate,
        NonInsurancePayerAddressUpdate_Remove,
        NonInsurancePayerAddressUpdate_Set,
    )
    from .non_insurance_payer_categories_page import NonInsurancePayerCategoriesPage
    from .non_insurance_payer_category_update import (
        NonInsurancePayerCategoryUpdate,
        NonInsurancePayerCategoryUpdate_Remove,
        NonInsurancePayerCategoryUpdate_Set,
    )
    from .non_insurance_payer_description_update import (
        NonInsurancePayerDescriptionUpdate,
        NonInsurancePayerDescriptionUpdate_Remove,
        NonInsurancePayerDescriptionUpdate_Set,
    )
    from .non_insurance_payer_id import NonInsurancePayerId
    from .non_insurance_payer_page import NonInsurancePayerPage
    from .non_insurance_payer_sort_field import NonInsurancePayerSortField
    from .non_insurance_payer_update_request import NonInsurancePayerUpdateRequest
    from .toggle_non_insurance_payer_enablement_request import ToggleNonInsurancePayerEnablementRequest
_dynamic_imports: typing.Dict[str, str] = {
    "CreateNonInsurancePayerRequest": ".create_non_insurance_payer_request",
    "NonInsurancePayer": ".non_insurance_payer",
    "NonInsurancePayerAddressUpdate": ".non_insurance_payer_address_update",
    "NonInsurancePayerAddressUpdate_Remove": ".non_insurance_payer_address_update",
    "NonInsurancePayerAddressUpdate_Set": ".non_insurance_payer_address_update",
    "NonInsurancePayerCategoriesPage": ".non_insurance_payer_categories_page",
    "NonInsurancePayerCategoryUpdate": ".non_insurance_payer_category_update",
    "NonInsurancePayerCategoryUpdate_Remove": ".non_insurance_payer_category_update",
    "NonInsurancePayerCategoryUpdate_Set": ".non_insurance_payer_category_update",
    "NonInsurancePayerDescriptionUpdate": ".non_insurance_payer_description_update",
    "NonInsurancePayerDescriptionUpdate_Remove": ".non_insurance_payer_description_update",
    "NonInsurancePayerDescriptionUpdate_Set": ".non_insurance_payer_description_update",
    "NonInsurancePayerId": ".non_insurance_payer_id",
    "NonInsurancePayerPage": ".non_insurance_payer_page",
    "NonInsurancePayerSortField": ".non_insurance_payer_sort_field",
    "NonInsurancePayerUpdateRequest": ".non_insurance_payer_update_request",
    "ToggleNonInsurancePayerEnablementRequest": ".toggle_non_insurance_payer_enablement_request",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "CreateNonInsurancePayerRequest",
    "NonInsurancePayer",
    "NonInsurancePayerAddressUpdate",
    "NonInsurancePayerAddressUpdate_Remove",
    "NonInsurancePayerAddressUpdate_Set",
    "NonInsurancePayerCategoriesPage",
    "NonInsurancePayerCategoryUpdate",
    "NonInsurancePayerCategoryUpdate_Remove",
    "NonInsurancePayerCategoryUpdate_Set",
    "NonInsurancePayerDescriptionUpdate",
    "NonInsurancePayerDescriptionUpdate_Remove",
    "NonInsurancePayerDescriptionUpdate_Set",
    "NonInsurancePayerId",
    "NonInsurancePayerPage",
    "NonInsurancePayerSortField",
    "NonInsurancePayerUpdateRequest",
    "ToggleNonInsurancePayerEnablementRequest",
]
