# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from . import (
        auth,
        billing_notes,
        charge_capture,
        charge_capture_bundles,
        claim_submission,
        claims,
        clinical_trials,
        commons,
        contracts,
        credentialing,
        custom_schemas,
        diagnoses,
        eligibility,
        encounter_attachments,
        encounter_providers,
        encounter_supplemental_information,
        encounters,
        encounters_universal,
        eras,
        events,
        exports,
        external_payment_account_config,
        fee_schedules,
        financials,
        guarantor,
        health_care_code_information,
        identifiers,
        import_invoice,
        individual,
        insurance_adjudications,
        insurance_cards,
        insurance_refunds,
        invoices,
        medication_dispense,
        non_insurance_payer_payments,
        non_insurance_payer_refunds,
        non_insurance_payers,
        organization_providers,
        organization_service_facilities,
        patient_ar,
        patient_payments,
        patient_refunds,
        payer_plan_groups,
        payers,
        payment_account_configs,
        pipeline_commons,
        pre_encounter,
        property_and_casualty,
        related_causes,
        service_facility,
        service_lines,
        superbills,
        tags,
        tasks,
        users,
        write_offs,
        x_12,
        yes_no_indicator,
    )
    from .claims import Claim, ClaimStatus
    from .commons import (
        AdjustmentId,
        AppointmentId,
        BadRequestError,
        BadRequestErrorMessage,
        BillingProviderCommercialLicenseType,
        ChargeCaptureClaimCreationId,
        ChargeCaptureId,
        ChargeCapturePostBilledChangeId,
        ClaimAdjustmentGroupCodes,
        ClaimId,
        ClaimSubmissionPayerResponsibilityType,
        Clearinghouse,
        ClinicalTrialId,
        Date,
        DateRangeOptionalEnd,
        Decimal,
        DelayReasonCode,
        Email,
        EmrPayerCrosswalk,
        EncounterExternalId,
        EncounterId,
        EntityConflictError,
        EntityConflictErrorMessage,
        EntityNotFoundError,
        EntityNotFoundErrorMessage,
        EpsdtReferralConditionIndicatorCode,
        ErrorMessage,
        FacilityTypeCode,
        HttpRequestValidationError,
        HttpRequestValidationsError,
        InsuranceTypeCode,
        IntendedSubmissionMedium,
        InternalError,
        InternalErrorMessage,
        InvoiceId,
        LinkUrl,
        NetworkType,
        NextResponsibleParty,
        Npi,
        OrganizationId,
        OrganizationNotAuthorizedError,
        OrganizationNotAuthorizedErrorMessage,
        PageToken,
        PatientExternalId,
        PatientRelationshipToInsuredCodeAll,
        PayerPlanGroupId,
        PhoneNumber,
        PhoneNumberOptional,
        PhoneNumberType,
        PreEncounterAppointmentId,
        PreEncounterPatientId,
        Primitive,
        ProcedureModifier,
        ProviderCredentialingSpanId,
        ProviderId,
        QualifierCode,
        RateId,
        RegionNational,
        RegionStates,
        Regions,
        Regions_National,
        Regions_States,
        RemovableDateRangeOptionalEnd,
        RemovableDateRangeOptionalEnd_DateRange,
        RemovableDateRangeOptionalEnd_Remove,
        ReportTransmissionCode,
        ReportTypeCode,
        RequestValidationError,
        ResourcePage,
        SchemaId,
        ServiceLineId,
        ServiceLineUnits,
        SortDirection,
        SourceOfPaymentCode,
        State,
        StreetAddressBase,
        StreetAddressLongZip,
        StreetAddressLongZipOptional,
        StreetAddressOptionalBase,
        StreetAddressShortZip,
        StreetAddressShortZipOptional,
        TaskAssignmentId,
        TaskId,
        TaskNoteId,
        UnauthorizedError,
        UnauthorizedErrorMessage,
        UnprocessableEntityError,
        UnprocessableEntityErrorMessage,
        UpdatesDisabledDueToExternalSystemIntegrationError,
        UpdatesDisabledDueToExternalSystemIntegrationErrorMessage,
        UserId,
        WorkQueueId,
    )
    from .diagnoses import (
        Diagnosis,
        DiagnosisCreate,
        DiagnosisCreateOptional,
        DiagnosisId,
        DiagnosisNotFoundError,
        DiagnosisNotFoundHttpError,
        DiagnosisTypeCode,
        DisallowMultiplePrimaryDiagnosisError,
        DisallowMultiplePrimaryDiagnosisHttpError,
        ServiceLinesMustHaveAtLeastOneDiagnosisError,
        ServiceLinesMustHaveAtLeastOneDiagnosisHttpError,
        StandaloneDiagnosisCreate,
    )
    from .eras import Era, EraBase, EraId
    from .financials import (
        AccountType,
        Allocation,
        AllocationCreate,
        AllocationEarmarkType,
        AllocationEarmarkType_DateOfService,
        AllocationEarmarkType_ExternalEncounterId,
        AllocationTarget,
        AllocationTargetCreate,
        AllocationTargetCreate_AppointmentByIdAndPatientExternalId,
        AllocationTargetCreate_BillingProviderById,
        AllocationTargetCreate_ClaimByEncounterExternalId,
        AllocationTargetCreate_ClaimById,
        AllocationTargetCreate_ServiceLineById,
        AllocationTargetCreate_Unattributed,
        AllocationTarget_Appointment,
        AllocationTarget_BillingProviderId,
        AllocationTarget_Claim,
        AllocationTarget_ServiceLine,
        AllocationTarget_Unattributed,
        AppointmentAllocationTarget,
        AppointmentByIdAndPatientExternalId,
        BalanceEarmark,
        BillingProviderAllocationTarget,
        ClaimAllocationTarget,
        InvoiceUpdate,
        InvoiceUpdate_Remove,
        InvoiceUpdate_Set,
        NoteUpdate,
        NoteUpdate_Remove,
        NoteUpdate_Set,
        PatientTransactionSource,
        RefundReason,
        RefundReasonUpdate,
        RefundReasonUpdate_Remove,
        RefundReasonUpdate_Set,
        ServiceLineAllocationTarget,
    )
    from .identifiers import (
        Identifier,
        IdentifierBase,
        IdentifierCode,
        IdentifierCreate,
        IdentifierId,
        IdentifierUpdate,
        IdentifierValue,
        IdentifierValue_MedicaidProviderIdentifier,
        IdentifierValue_MedicareProviderIdentifier,
        MedicaidProviderIdentifier,
        MedicareProviderIdentifier,
        UpdatableIdentifier,
        UpdatableIdentifier_Add,
        UpdatableIdentifier_Remove,
        UpdatableIdentifier_Update,
    )
    from .individual import (
        Gender,
        IndividualBase,
        IndividualBaseOptional,
        IndividualId,
        Patient,
        PatientBase,
        PatientClinicalTrialInfo,
        PatientClinicalTrialInfoCreate,
        PatientCreate,
        PatientNonInsurancePayerInfo,
        PatientNonInsurancePayerInfoCreate,
        PatientNonInsurancePayerInfoCreateOptional,
        PatientUpdate,
        PatientUpdateWithOptionalAddress,
        Subscriber,
        SubscriberBase,
        SubscriberBaseOptional,
        SubscriberCreate,
        SubscriberCreateOptional,
    )
    from .invoices import Invoice, InvoiceItem, InvoiceStatus
    from .payment_account_configs import PaymentAccountConfigId
    from .pipeline_commons import ConfigurableRuleId
    from .service_facility import (
        EncounterServiceFacility,
        EncounterServiceFacilityBase,
        EncounterServiceFacilityUpdate,
        EncounterServiceFacilityUpdateWithOptionalAddress,
        ServiceFacilityId,
    )
    from .tags import Tag, TagColorEnum, TagCreate, TagId
    from .yes_no_indicator import YesNoIndicator
_dynamic_imports: typing.Dict[str, str] = {
    "AccountType": ".financials",
    "AdjustmentId": ".commons",
    "Allocation": ".financials",
    "AllocationCreate": ".financials",
    "AllocationEarmarkType": ".financials",
    "AllocationEarmarkType_DateOfService": ".financials",
    "AllocationEarmarkType_ExternalEncounterId": ".financials",
    "AllocationTarget": ".financials",
    "AllocationTargetCreate": ".financials",
    "AllocationTargetCreate_AppointmentByIdAndPatientExternalId": ".financials",
    "AllocationTargetCreate_BillingProviderById": ".financials",
    "AllocationTargetCreate_ClaimByEncounterExternalId": ".financials",
    "AllocationTargetCreate_ClaimById": ".financials",
    "AllocationTargetCreate_ServiceLineById": ".financials",
    "AllocationTargetCreate_Unattributed": ".financials",
    "AllocationTarget_Appointment": ".financials",
    "AllocationTarget_BillingProviderId": ".financials",
    "AllocationTarget_Claim": ".financials",
    "AllocationTarget_ServiceLine": ".financials",
    "AllocationTarget_Unattributed": ".financials",
    "AppointmentAllocationTarget": ".financials",
    "AppointmentByIdAndPatientExternalId": ".financials",
    "AppointmentId": ".commons",
    "BadRequestError": ".commons",
    "BadRequestErrorMessage": ".commons",
    "BalanceEarmark": ".financials",
    "BillingProviderAllocationTarget": ".financials",
    "BillingProviderCommercialLicenseType": ".commons",
    "ChargeCaptureClaimCreationId": ".commons",
    "ChargeCaptureId": ".commons",
    "ChargeCapturePostBilledChangeId": ".commons",
    "Claim": ".claims",
    "ClaimAdjustmentGroupCodes": ".commons",
    "ClaimAllocationTarget": ".financials",
    "ClaimId": ".commons",
    "ClaimStatus": ".claims",
    "ClaimSubmissionPayerResponsibilityType": ".commons",
    "Clearinghouse": ".commons",
    "ClinicalTrialId": ".commons",
    "ConfigurableRuleId": ".pipeline_commons",
    "Date": ".commons",
    "DateRangeOptionalEnd": ".commons",
    "Decimal": ".commons",
    "DelayReasonCode": ".commons",
    "Diagnosis": ".diagnoses",
    "DiagnosisCreate": ".diagnoses",
    "DiagnosisCreateOptional": ".diagnoses",
    "DiagnosisId": ".diagnoses",
    "DiagnosisNotFoundError": ".diagnoses",
    "DiagnosisNotFoundHttpError": ".diagnoses",
    "DiagnosisTypeCode": ".diagnoses",
    "DisallowMultiplePrimaryDiagnosisError": ".diagnoses",
    "DisallowMultiplePrimaryDiagnosisHttpError": ".diagnoses",
    "Email": ".commons",
    "EmrPayerCrosswalk": ".commons",
    "EncounterExternalId": ".commons",
    "EncounterId": ".commons",
    "EncounterServiceFacility": ".service_facility",
    "EncounterServiceFacilityBase": ".service_facility",
    "EncounterServiceFacilityUpdate": ".service_facility",
    "EncounterServiceFacilityUpdateWithOptionalAddress": ".service_facility",
    "EntityConflictError": ".commons",
    "EntityConflictErrorMessage": ".commons",
    "EntityNotFoundError": ".commons",
    "EntityNotFoundErrorMessage": ".commons",
    "EpsdtReferralConditionIndicatorCode": ".commons",
    "Era": ".eras",
    "EraBase": ".eras",
    "EraId": ".eras",
    "ErrorMessage": ".commons",
    "FacilityTypeCode": ".commons",
    "Gender": ".individual",
    "HttpRequestValidationError": ".commons",
    "HttpRequestValidationsError": ".commons",
    "Identifier": ".identifiers",
    "IdentifierBase": ".identifiers",
    "IdentifierCode": ".identifiers",
    "IdentifierCreate": ".identifiers",
    "IdentifierId": ".identifiers",
    "IdentifierUpdate": ".identifiers",
    "IdentifierValue": ".identifiers",
    "IdentifierValue_MedicaidProviderIdentifier": ".identifiers",
    "IdentifierValue_MedicareProviderIdentifier": ".identifiers",
    "IndividualBase": ".individual",
    "IndividualBaseOptional": ".individual",
    "IndividualId": ".individual",
    "InsuranceTypeCode": ".commons",
    "IntendedSubmissionMedium": ".commons",
    "InternalError": ".commons",
    "InternalErrorMessage": ".commons",
    "Invoice": ".invoices",
    "InvoiceId": ".commons",
    "InvoiceItem": ".invoices",
    "InvoiceStatus": ".invoices",
    "InvoiceUpdate": ".financials",
    "InvoiceUpdate_Remove": ".financials",
    "InvoiceUpdate_Set": ".financials",
    "LinkUrl": ".commons",
    "MedicaidProviderIdentifier": ".identifiers",
    "MedicareProviderIdentifier": ".identifiers",
    "NetworkType": ".commons",
    "NextResponsibleParty": ".commons",
    "NoteUpdate": ".financials",
    "NoteUpdate_Remove": ".financials",
    "NoteUpdate_Set": ".financials",
    "Npi": ".commons",
    "OrganizationId": ".commons",
    "OrganizationNotAuthorizedError": ".commons",
    "OrganizationNotAuthorizedErrorMessage": ".commons",
    "PageToken": ".commons",
    "Patient": ".individual",
    "PatientBase": ".individual",
    "PatientClinicalTrialInfo": ".individual",
    "PatientClinicalTrialInfoCreate": ".individual",
    "PatientCreate": ".individual",
    "PatientExternalId": ".commons",
    "PatientNonInsurancePayerInfo": ".individual",
    "PatientNonInsurancePayerInfoCreate": ".individual",
    "PatientNonInsurancePayerInfoCreateOptional": ".individual",
    "PatientRelationshipToInsuredCodeAll": ".commons",
    "PatientTransactionSource": ".financials",
    "PatientUpdate": ".individual",
    "PatientUpdateWithOptionalAddress": ".individual",
    "PayerPlanGroupId": ".commons",
    "PaymentAccountConfigId": ".payment_account_configs",
    "PhoneNumber": ".commons",
    "PhoneNumberOptional": ".commons",
    "PhoneNumberType": ".commons",
    "PreEncounterAppointmentId": ".commons",
    "PreEncounterPatientId": ".commons",
    "Primitive": ".commons",
    "ProcedureModifier": ".commons",
    "ProviderCredentialingSpanId": ".commons",
    "ProviderId": ".commons",
    "QualifierCode": ".commons",
    "RateId": ".commons",
    "RefundReason": ".financials",
    "RefundReasonUpdate": ".financials",
    "RefundReasonUpdate_Remove": ".financials",
    "RefundReasonUpdate_Set": ".financials",
    "RegionNational": ".commons",
    "RegionStates": ".commons",
    "Regions": ".commons",
    "Regions_National": ".commons",
    "Regions_States": ".commons",
    "RemovableDateRangeOptionalEnd": ".commons",
    "RemovableDateRangeOptionalEnd_DateRange": ".commons",
    "RemovableDateRangeOptionalEnd_Remove": ".commons",
    "ReportTransmissionCode": ".commons",
    "ReportTypeCode": ".commons",
    "RequestValidationError": ".commons",
    "ResourcePage": ".commons",
    "SchemaId": ".commons",
    "ServiceFacilityId": ".service_facility",
    "ServiceLineAllocationTarget": ".financials",
    "ServiceLineId": ".commons",
    "ServiceLineUnits": ".commons",
    "ServiceLinesMustHaveAtLeastOneDiagnosisError": ".diagnoses",
    "ServiceLinesMustHaveAtLeastOneDiagnosisHttpError": ".diagnoses",
    "SortDirection": ".commons",
    "SourceOfPaymentCode": ".commons",
    "StandaloneDiagnosisCreate": ".diagnoses",
    "State": ".commons",
    "StreetAddressBase": ".commons",
    "StreetAddressLongZip": ".commons",
    "StreetAddressLongZipOptional": ".commons",
    "StreetAddressOptionalBase": ".commons",
    "StreetAddressShortZip": ".commons",
    "StreetAddressShortZipOptional": ".commons",
    "Subscriber": ".individual",
    "SubscriberBase": ".individual",
    "SubscriberBaseOptional": ".individual",
    "SubscriberCreate": ".individual",
    "SubscriberCreateOptional": ".individual",
    "Tag": ".tags",
    "TagColorEnum": ".tags",
    "TagCreate": ".tags",
    "TagId": ".tags",
    "TaskAssignmentId": ".commons",
    "TaskId": ".commons",
    "TaskNoteId": ".commons",
    "UnauthorizedError": ".commons",
    "UnauthorizedErrorMessage": ".commons",
    "UnprocessableEntityError": ".commons",
    "UnprocessableEntityErrorMessage": ".commons",
    "UpdatableIdentifier": ".identifiers",
    "UpdatableIdentifier_Add": ".identifiers",
    "UpdatableIdentifier_Remove": ".identifiers",
    "UpdatableIdentifier_Update": ".identifiers",
    "UpdatesDisabledDueToExternalSystemIntegrationError": ".commons",
    "UpdatesDisabledDueToExternalSystemIntegrationErrorMessage": ".commons",
    "UserId": ".commons",
    "WorkQueueId": ".commons",
    "YesNoIndicator": ".yes_no_indicator",
    "auth": ".auth",
    "billing_notes": ".billing_notes",
    "charge_capture": ".charge_capture",
    "charge_capture_bundles": ".charge_capture_bundles",
    "claim_submission": ".claim_submission",
    "claims": ".claims",
    "clinical_trials": ".clinical_trials",
    "commons": ".commons",
    "contracts": ".contracts",
    "credentialing": ".credentialing",
    "custom_schemas": ".custom_schemas",
    "diagnoses": ".diagnoses",
    "eligibility": ".eligibility",
    "encounter_attachments": ".encounter_attachments",
    "encounter_providers": ".encounter_providers",
    "encounter_supplemental_information": ".encounter_supplemental_information",
    "encounters": ".encounters",
    "encounters_universal": ".encounters_universal",
    "eras": ".eras",
    "events": ".events",
    "exports": ".exports",
    "external_payment_account_config": ".external_payment_account_config",
    "fee_schedules": ".fee_schedules",
    "financials": ".financials",
    "guarantor": ".guarantor",
    "health_care_code_information": ".health_care_code_information",
    "identifiers": ".identifiers",
    "import_invoice": ".import_invoice",
    "individual": ".individual",
    "insurance_adjudications": ".insurance_adjudications",
    "insurance_cards": ".insurance_cards",
    "insurance_refunds": ".insurance_refunds",
    "invoices": ".invoices",
    "medication_dispense": ".medication_dispense",
    "non_insurance_payer_payments": ".non_insurance_payer_payments",
    "non_insurance_payer_refunds": ".non_insurance_payer_refunds",
    "non_insurance_payers": ".non_insurance_payers",
    "organization_providers": ".organization_providers",
    "organization_service_facilities": ".organization_service_facilities",
    "patient_ar": ".patient_ar",
    "patient_payments": ".patient_payments",
    "patient_refunds": ".patient_refunds",
    "payer_plan_groups": ".payer_plan_groups",
    "payers": ".payers",
    "payment_account_configs": ".payment_account_configs",
    "pipeline_commons": ".pipeline_commons",
    "pre_encounter": ".pre_encounter",
    "property_and_casualty": ".property_and_casualty",
    "related_causes": ".related_causes",
    "service_facility": ".service_facility",
    "service_lines": ".service_lines",
    "superbills": ".superbills",
    "tags": ".tags",
    "tasks": ".tasks",
    "users": ".users",
    "write_offs": ".write_offs",
    "x_12": ".x_12",
    "yes_no_indicator": ".yes_no_indicator",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AccountType",
    "AdjustmentId",
    "Allocation",
    "AllocationCreate",
    "AllocationEarmarkType",
    "AllocationEarmarkType_DateOfService",
    "AllocationEarmarkType_ExternalEncounterId",
    "AllocationTarget",
    "AllocationTargetCreate",
    "AllocationTargetCreate_AppointmentByIdAndPatientExternalId",
    "AllocationTargetCreate_BillingProviderById",
    "AllocationTargetCreate_ClaimByEncounterExternalId",
    "AllocationTargetCreate_ClaimById",
    "AllocationTargetCreate_ServiceLineById",
    "AllocationTargetCreate_Unattributed",
    "AllocationTarget_Appointment",
    "AllocationTarget_BillingProviderId",
    "AllocationTarget_Claim",
    "AllocationTarget_ServiceLine",
    "AllocationTarget_Unattributed",
    "AppointmentAllocationTarget",
    "AppointmentByIdAndPatientExternalId",
    "AppointmentId",
    "BadRequestError",
    "BadRequestErrorMessage",
    "BalanceEarmark",
    "BillingProviderAllocationTarget",
    "BillingProviderCommercialLicenseType",
    "ChargeCaptureClaimCreationId",
    "ChargeCaptureId",
    "ChargeCapturePostBilledChangeId",
    "Claim",
    "ClaimAdjustmentGroupCodes",
    "ClaimAllocationTarget",
    "ClaimId",
    "ClaimStatus",
    "ClaimSubmissionPayerResponsibilityType",
    "Clearinghouse",
    "ClinicalTrialId",
    "ConfigurableRuleId",
    "Date",
    "DateRangeOptionalEnd",
    "Decimal",
    "DelayReasonCode",
    "Diagnosis",
    "DiagnosisCreate",
    "DiagnosisCreateOptional",
    "DiagnosisId",
    "DiagnosisNotFoundError",
    "DiagnosisNotFoundHttpError",
    "DiagnosisTypeCode",
    "DisallowMultiplePrimaryDiagnosisError",
    "DisallowMultiplePrimaryDiagnosisHttpError",
    "Email",
    "EmrPayerCrosswalk",
    "EncounterExternalId",
    "EncounterId",
    "EncounterServiceFacility",
    "EncounterServiceFacilityBase",
    "EncounterServiceFacilityUpdate",
    "EncounterServiceFacilityUpdateWithOptionalAddress",
    "EntityConflictError",
    "EntityConflictErrorMessage",
    "EntityNotFoundError",
    "EntityNotFoundErrorMessage",
    "EpsdtReferralConditionIndicatorCode",
    "Era",
    "EraBase",
    "EraId",
    "ErrorMessage",
    "FacilityTypeCode",
    "Gender",
    "HttpRequestValidationError",
    "HttpRequestValidationsError",
    "Identifier",
    "IdentifierBase",
    "IdentifierCode",
    "IdentifierCreate",
    "IdentifierId",
    "IdentifierUpdate",
    "IdentifierValue",
    "IdentifierValue_MedicaidProviderIdentifier",
    "IdentifierValue_MedicareProviderIdentifier",
    "IndividualBase",
    "IndividualBaseOptional",
    "IndividualId",
    "InsuranceTypeCode",
    "IntendedSubmissionMedium",
    "InternalError",
    "InternalErrorMessage",
    "Invoice",
    "InvoiceId",
    "InvoiceItem",
    "InvoiceStatus",
    "InvoiceUpdate",
    "InvoiceUpdate_Remove",
    "InvoiceUpdate_Set",
    "LinkUrl",
    "MedicaidProviderIdentifier",
    "MedicareProviderIdentifier",
    "NetworkType",
    "NextResponsibleParty",
    "NoteUpdate",
    "NoteUpdate_Remove",
    "NoteUpdate_Set",
    "Npi",
    "OrganizationId",
    "OrganizationNotAuthorizedError",
    "OrganizationNotAuthorizedErrorMessage",
    "PageToken",
    "Patient",
    "PatientBase",
    "PatientClinicalTrialInfo",
    "PatientClinicalTrialInfoCreate",
    "PatientCreate",
    "PatientExternalId",
    "PatientNonInsurancePayerInfo",
    "PatientNonInsurancePayerInfoCreate",
    "PatientNonInsurancePayerInfoCreateOptional",
    "PatientRelationshipToInsuredCodeAll",
    "PatientTransactionSource",
    "PatientUpdate",
    "PatientUpdateWithOptionalAddress",
    "PayerPlanGroupId",
    "PaymentAccountConfigId",
    "PhoneNumber",
    "PhoneNumberOptional",
    "PhoneNumberType",
    "PreEncounterAppointmentId",
    "PreEncounterPatientId",
    "Primitive",
    "ProcedureModifier",
    "ProviderCredentialingSpanId",
    "ProviderId",
    "QualifierCode",
    "RateId",
    "RefundReason",
    "RefundReasonUpdate",
    "RefundReasonUpdate_Remove",
    "RefundReasonUpdate_Set",
    "RegionNational",
    "RegionStates",
    "Regions",
    "Regions_National",
    "Regions_States",
    "RemovableDateRangeOptionalEnd",
    "RemovableDateRangeOptionalEnd_DateRange",
    "RemovableDateRangeOptionalEnd_Remove",
    "ReportTransmissionCode",
    "ReportTypeCode",
    "RequestValidationError",
    "ResourcePage",
    "SchemaId",
    "ServiceFacilityId",
    "ServiceLineAllocationTarget",
    "ServiceLineId",
    "ServiceLineUnits",
    "ServiceLinesMustHaveAtLeastOneDiagnosisError",
    "ServiceLinesMustHaveAtLeastOneDiagnosisHttpError",
    "SortDirection",
    "SourceOfPaymentCode",
    "StandaloneDiagnosisCreate",
    "State",
    "StreetAddressBase",
    "StreetAddressLongZip",
    "StreetAddressLongZipOptional",
    "StreetAddressOptionalBase",
    "StreetAddressShortZip",
    "StreetAddressShortZipOptional",
    "Subscriber",
    "SubscriberBase",
    "SubscriberBaseOptional",
    "SubscriberCreate",
    "SubscriberCreateOptional",
    "Tag",
    "TagColorEnum",
    "TagCreate",
    "TagId",
    "TaskAssignmentId",
    "TaskId",
    "TaskNoteId",
    "UnauthorizedError",
    "UnauthorizedErrorMessage",
    "UnprocessableEntityError",
    "UnprocessableEntityErrorMessage",
    "UpdatableIdentifier",
    "UpdatableIdentifier_Add",
    "UpdatableIdentifier_Remove",
    "UpdatableIdentifier_Update",
    "UpdatesDisabledDueToExternalSystemIntegrationError",
    "UpdatesDisabledDueToExternalSystemIntegrationErrorMessage",
    "UserId",
    "WorkQueueId",
    "YesNoIndicator",
    "auth",
    "billing_notes",
    "charge_capture",
    "charge_capture_bundles",
    "claim_submission",
    "claims",
    "clinical_trials",
    "commons",
    "contracts",
    "credentialing",
    "custom_schemas",
    "diagnoses",
    "eligibility",
    "encounter_attachments",
    "encounter_providers",
    "encounter_supplemental_information",
    "encounters",
    "encounters_universal",
    "eras",
    "events",
    "exports",
    "external_payment_account_config",
    "fee_schedules",
    "financials",
    "guarantor",
    "health_care_code_information",
    "identifiers",
    "import_invoice",
    "individual",
    "insurance_adjudications",
    "insurance_cards",
    "insurance_refunds",
    "invoices",
    "medication_dispense",
    "non_insurance_payer_payments",
    "non_insurance_payer_refunds",
    "non_insurance_payers",
    "organization_providers",
    "organization_service_facilities",
    "patient_ar",
    "patient_payments",
    "patient_refunds",
    "payer_plan_groups",
    "payers",
    "payment_account_configs",
    "pipeline_commons",
    "pre_encounter",
    "property_and_casualty",
    "related_causes",
    "service_facility",
    "service_lines",
    "superbills",
    "tags",
    "tasks",
    "users",
    "write_offs",
    "x_12",
    "yes_no_indicator",
]
