# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.primitive import Primitive


class SchemaField(UniversalBaseModel):
    """
    Examples
    --------
    from candid.resources.commons import Primitive
    from candid.resources.custom_schemas.resources.v_1 import SchemaField

    SchemaField(
        key="provider_category",
        type=Primitive.STRING,
    )
    """

    key: str
    type: Primitive

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
