# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.claim_id import ClaimId
from .....commons.types.encounter_id import EncounterId
from .....commons.types.patient_external_id import PatientExternalId
from .patient_ar_status import PatientArStatus


class InventoryRecord(UniversalBaseModel):
    claim_id: ClaimId
    encounter_id: EncounterId
    timestamp: dt.datetime
    patient_external_id: PatientExternalId
    patient_ar_status: PatientArStatus

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
