# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class VitalsUpdate(UniversalBaseModel):
    """
    Examples
    --------
    from candid.resources.encounters.resources.v_4 import VitalsUpdate

    VitalsUpdate(
        height_in=70,
        weight_lbs=165,
        blood_pressure_systolic_mmhg=115,
        blood_pressure_diastolic_mmhg=85,
        body_temperature_f=98.0,
        hemoglobin_gdl=15.1,
        hematocrit_pct=51.2,
    )
    """

    height_in: typing.Optional[int] = None
    weight_lbs: typing.Optional[int] = None
    blood_pressure_systolic_mmhg: typing.Optional[int] = None
    blood_pressure_diastolic_mmhg: typing.Optional[int] = None
    body_temperature_f: typing.Optional[float] = None
    hemoglobin_gdl: typing.Optional[float] = None
    hematocrit_pct: typing.Optional[float] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
