# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .d_8_date import D8Date
from .health_care_code_information_new import HealthCareCodeInformationNew
from .icd_code import IcdCode
from .other_procedure_information_code_qualifier import OtherProcedureInformationCodeQualifier


class OtherProcedureInformationNew(HealthCareCodeInformationNew):
    """
    This corresponds to the BBQ or BQ code qualifier values.
    """

    other_procedure_code_qualifier: OtherProcedureInformationCodeQualifier
    other_procedure_code: IcdCode
    other_procedure_date: D8Date = pydantic.Field()
    """
    An [RFC 3339, section 5.6 datetime](https://ijmacd.github.io/rfc3339-iso8601/).
    For example, 2017-07-21T17:32:28Z.
    In practice, only the date portion of this is used for claim submission, so
    midnight time is fine.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
