# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        CreateWriteOffsResponse,
        InsuranceWriteOff,
        InsuranceWriteOffCreate,
        InsuranceWriteOffReason,
        InsuranceWriteOffTarget,
        InsuranceWriteOffTarget_BillingProviderId,
        InsuranceWriteOffTarget_ClaimId,
        InsuranceWriteOffTarget_ServiceLineId,
        NonInsurancePayerWriteOff,
        NonInsurancePayerWriteOffCreate,
        PatientWriteOff,
        PatientWriteOffCreate,
        PatientWriteOffReason,
        WriteOff,
        WriteOffCreate,
        WriteOffCreate_Insurance,
        WriteOffCreate_NonInsurancePayer,
        WriteOffCreate_Patient,
        WriteOffId,
        WriteOffSortField,
        WriteOff_Insurance,
        WriteOff_NonInsurancePayer,
        WriteOff_Patient,
        WriteOffsPage,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "CreateWriteOffsResponse": ".types",
    "InsuranceWriteOff": ".types",
    "InsuranceWriteOffCreate": ".types",
    "InsuranceWriteOffReason": ".types",
    "InsuranceWriteOffTarget": ".types",
    "InsuranceWriteOffTarget_BillingProviderId": ".types",
    "InsuranceWriteOffTarget_ClaimId": ".types",
    "InsuranceWriteOffTarget_ServiceLineId": ".types",
    "NonInsurancePayerWriteOff": ".types",
    "NonInsurancePayerWriteOffCreate": ".types",
    "PatientWriteOff": ".types",
    "PatientWriteOffCreate": ".types",
    "PatientWriteOffReason": ".types",
    "WriteOff": ".types",
    "WriteOffCreate": ".types",
    "WriteOffCreate_Insurance": ".types",
    "WriteOffCreate_NonInsurancePayer": ".types",
    "WriteOffCreate_Patient": ".types",
    "WriteOffId": ".types",
    "WriteOffSortField": ".types",
    "WriteOff_Insurance": ".types",
    "WriteOff_NonInsurancePayer": ".types",
    "WriteOff_Patient": ".types",
    "WriteOffsPage": ".types",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "CreateWriteOffsResponse",
    "InsuranceWriteOff",
    "InsuranceWriteOffCreate",
    "InsuranceWriteOffReason",
    "InsuranceWriteOffTarget",
    "InsuranceWriteOffTarget_BillingProviderId",
    "InsuranceWriteOffTarget_ClaimId",
    "InsuranceWriteOffTarget_ServiceLineId",
    "NonInsurancePayerWriteOff",
    "NonInsurancePayerWriteOffCreate",
    "PatientWriteOff",
    "PatientWriteOffCreate",
    "PatientWriteOffReason",
    "WriteOff",
    "WriteOffCreate",
    "WriteOffCreate_Insurance",
    "WriteOffCreate_NonInsurancePayer",
    "WriteOffCreate_Patient",
    "WriteOffId",
    "WriteOffSortField",
    "WriteOff_Insurance",
    "WriteOff_NonInsurancePayer",
    "WriteOff_Patient",
    "WriteOffsPage",
]
