# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .....commons.types.decimal import Decimal
from .health_care_code_information_new import HealthCareCodeInformationNew
from .value_code import ValueCode
from .value_code_qualifier import ValueCodeQualifier


class ValueInformationNew(HealthCareCodeInformationNew):
    """
    This corresponds to the BE code qualifier value.
    """

    value_code_qualifier: ValueCodeQualifier
    value_code: ValueCode
    value_code_amount: Decimal

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
