# This file was auto-generated by Fern from our API Definition.

import typing

from ......core.api_error import ApiError
from ..types.payer_plan_group_payer_does_not_match_insurance_card_error import (
    PayerPlanGroupPayerDoesNotMatchInsuranceCardError,
)


class PayerPlanGroupPayerDoesNotMatchInsuranceCardHttpError(ApiError):
    def __init__(
        self,
        body: PayerPlanGroupPayerDoesNotMatchInsuranceCardError,
        headers: typing.Optional[typing.Dict[str, str]] = None,
    ):
        super().__init__(status_code=422, headers=headers, body=body)
