# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .....organization_service_facilities.resources.v_2.types.organization_service_facility import (
    OrganizationServiceFacility,
)
from .base_credentialing_span import BaseCredentialingSpan
from .facility_credentialing_span_id import FacilityCredentialingSpanId


class FacilityCredentialingSpan(BaseCredentialingSpan):
    facility_credentialing_span_id: FacilityCredentialingSpanId
    service_facility: OrganizationServiceFacility = pydantic.Field()
    """
    The service facility covered by the credentialing span.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
