# This file was auto-generated by Fern from our API Definition.

import typing

from ........core import enum

T_Result = typing.TypeVar("T_Result")


class CoverageValueUnit(enum.StrEnum):
    PERCENT = "PERCENT"
    CURRENCY = "CURRENCY"
    COUNT = "COUNT"
    _UNKNOWN = "__COVERAGEVALUEUNIT_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "CoverageValueUnit":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        percent: typing.Callable[[], T_Result],
        currency: typing.Callable[[], T_Result],
        count: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is CoverageValueUnit.PERCENT:
            return percent()
        if self is CoverageValueUnit.CURRENCY:
            return currency()
        if self is CoverageValueUnit.COUNT:
            return count()
        return _unknown_member(self._value_)
