# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ...insurance_cards.resources.v_2.types.insurance_card_create_optional import InsuranceCardCreateOptional
from .subscriber_base_optional import SubscriberBaseOptional


class SubscriberCreateOptional(SubscriberBaseOptional):
    insurance_card: typing.Optional[InsuranceCardCreateOptional] = pydantic.Field(default=None)
    """
    Please reference our [Payer Information](https://docs.joincandidhealth.com/introduction/payer-information) documentation for more details on how to populate the `insurance_card` fields.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
