# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .raw_client import AsyncRawCoveragesClient, RawCoveragesClient

if typing.TYPE_CHECKING:
    from .resources.v_1.client import AsyncV1Client, V1Client


class CoveragesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawCoveragesClient(client_wrapper=client_wrapper)
        self._client_wrapper = client_wrapper
        self._v_1: typing.Optional[V1Client] = None

    @property
    def with_raw_response(self) -> RawCoveragesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawCoveragesClient
        """
        return self._raw_client

    @property
    def v_1(self):
        if self._v_1 is None:
            from .resources.v_1.client import V1Client  # noqa: E402

            self._v_1 = V1Client(client_wrapper=self._client_wrapper)
        return self._v_1


class AsyncCoveragesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawCoveragesClient(client_wrapper=client_wrapper)
        self._client_wrapper = client_wrapper
        self._v_1: typing.Optional[AsyncV1Client] = None

    @property
    def with_raw_response(self) -> AsyncRawCoveragesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawCoveragesClient
        """
        return self._raw_client

    @property
    def v_1(self):
        if self._v_1 is None:
            from .resources.v_1.client import AsyncV1Client  # noqa: E402

            self._v_1 = AsyncV1Client(client_wrapper=self._client_wrapper)
        return self._v_1
