# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class PatientHistoryCategoryEnum(enum.StrEnum):
    PRESENT_ILLNESS = "present_illness"
    MEDICAL = "medical"
    FAMILY = "family"
    SOCIAL = "social"
    _UNKNOWN = "__PATIENTHISTORYCATEGORYENUM_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "PatientHistoryCategoryEnum":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        present_illness: typing.Callable[[], T_Result],
        medical: typing.Callable[[], T_Result],
        family: typing.Callable[[], T_Result],
        social: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is PatientHistoryCategoryEnum.PRESENT_ILLNESS:
            return present_illness()
        if self is PatientHistoryCategoryEnum.MEDICAL:
            return medical()
        if self is PatientHistoryCategoryEnum.FAMILY:
            return family()
        if self is PatientHistoryCategoryEnum.SOCIAL:
            return social()
        return _unknown_member(self._value_)
