# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class DiagnosisRelatedGroupCodeQualifier(enum.StrEnum):
    CDR = "DR"
    """
    Diagnosis Related Group (DRG)
    """

    _UNKNOWN = "__DIAGNOSISRELATEDGROUPCODEQUALIFIER_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "DiagnosisRelatedGroupCodeQualifier":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(self, cdr: typing.Callable[[], T_Result], _unknown_member: typing.Callable[[str], T_Result]) -> T_Result:
        if self is DiagnosisRelatedGroupCodeQualifier.CDR:
            return cdr()
        return _unknown_member(self._value_)
