# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .measurement_unit_code import MeasurementUnitCode
from .service_id_qualifier import ServiceIdQualifier


class DrugIdentificationOptional(UniversalBaseModel):
    service_id_qualifier: typing.Optional[ServiceIdQualifier] = None
    national_drug_code: typing.Optional[str] = None
    national_drug_unit_count: typing.Optional[str] = None
    measurement_unit_code: typing.Optional[MeasurementUnitCode] = None
    link_sequence_number: typing.Optional[str] = None
    pharmacy_prescription_number: typing.Optional[str] = None
    conversion_formula: typing.Optional[str] = None
    drug_description: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
