# This file was auto-generated by Fern from our API Definition.

import typing

from ....core.api_error import ApiError
from ..types.organization_not_authorized_error_message import OrganizationNotAuthorizedErrorMessage


class OrganizationNotAuthorizedError(ApiError):
    def __init__(
        self, body: OrganizationNotAuthorizedErrorMessage, headers: typing.Optional[typing.Dict[str, str]] = None
    ):
        super().__init__(status_code=400, headers=headers, body=body)
