# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        Address,
        BenefitType,
        BenefitsRelatedEntity,
        Coverage,
        CoverageBenefits,
        CoverageDetails,
        CoverageEligibilityCheckResponse,
        CoverageLevel,
        CoverageStatus,
        CoverageValue,
        CoverageValueUnit,
        CoveragesPage,
        ExpandedMemberInfo,
        InsurancePlan,
        InsuranceTypeCode,
        LatestEligibilityCheck,
        MemberInfo,
        MutableCoverage,
        NetworkType,
        PayerPlanGroupFields,
        PlanCoverage,
        PlanCoverageDetails,
        PlanDate,
        PlanMetadata,
        RelatedEntityContact,
        ServiceCoverage,
        ServiceCoverageDetails,
        ServiceTypeCode,
        Subscriber,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "Address": ".types",
    "BenefitType": ".types",
    "BenefitsRelatedEntity": ".types",
    "Coverage": ".types",
    "CoverageBenefits": ".types",
    "CoverageDetails": ".types",
    "CoverageEligibilityCheckResponse": ".types",
    "CoverageLevel": ".types",
    "CoverageStatus": ".types",
    "CoverageValue": ".types",
    "CoverageValueUnit": ".types",
    "CoveragesPage": ".types",
    "ExpandedMemberInfo": ".types",
    "InsurancePlan": ".types",
    "InsuranceTypeCode": ".types",
    "LatestEligibilityCheck": ".types",
    "MemberInfo": ".types",
    "MutableCoverage": ".types",
    "NetworkType": ".types",
    "PayerPlanGroupFields": ".types",
    "PlanCoverage": ".types",
    "PlanCoverageDetails": ".types",
    "PlanDate": ".types",
    "PlanMetadata": ".types",
    "RelatedEntityContact": ".types",
    "ServiceCoverage": ".types",
    "ServiceCoverageDetails": ".types",
    "ServiceTypeCode": ".types",
    "Subscriber": ".types",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "Address",
    "BenefitType",
    "BenefitsRelatedEntity",
    "Coverage",
    "CoverageBenefits",
    "CoverageDetails",
    "CoverageEligibilityCheckResponse",
    "CoverageLevel",
    "CoverageStatus",
    "CoverageValue",
    "CoverageValueUnit",
    "CoveragesPage",
    "ExpandedMemberInfo",
    "InsurancePlan",
    "InsuranceTypeCode",
    "LatestEligibilityCheck",
    "MemberInfo",
    "MutableCoverage",
    "NetworkType",
    "PayerPlanGroupFields",
    "PlanCoverage",
    "PlanCoverageDetails",
    "PlanDate",
    "PlanMetadata",
    "RelatedEntityContact",
    "ServiceCoverage",
    "ServiceCoverageDetails",
    "ServiceTypeCode",
    "Subscriber",
]
