# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .user_configured_prompts_result import UserConfiguredPromptsResult


class UserConfiguredPromptsRecommendationPayload(UniversalBaseModel):
    """
    Payload for user-configured prompt recommendations from AI analysis
    """

    results: typing.List[UserConfiguredPromptsResult] = pydantic.Field()
    """
    Array of results from all enabled user-configured prompts
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
