# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .coverage_association import CoverageAssociation
from .image_status import ImageStatus
from .patient_association import PatientAssociation


class MutableImage(UniversalBaseModel):
    """
    An object representing an Image.
    """

    file_name: str
    display_name: str
    file_type: str
    status: ImageStatus
    coverage: typing.Optional[CoverageAssociation] = None
    patient: typing.Optional[PatientAssociation] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
