# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class EncounterAttachmentType(enum.StrEnum):
    DOCUMENTATION = "DOCUMENTATION"
    EOB = "EOB"
    OTHER = "OTHER"
    _UNKNOWN = "__ENCOUNTERATTACHMENTTYPE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "EncounterAttachmentType":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        documentation: typing.Callable[[], T_Result],
        eob: typing.Callable[[], T_Result],
        other: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is EncounterAttachmentType.DOCUMENTATION:
            return documentation()
        if self is EncounterAttachmentType.EOB:
            return eob()
        if self is EncounterAttachmentType.OTHER:
            return other()
        return _unknown_member(self._value_)
