# This file was auto-generated by Fern from our API Definition.

import typing

from ........core import enum

T_Result = typing.TypeVar("T_Result")


class ReferralSource(enum.StrEnum):
    HOSPITAL = "HOSPITAL"
    REFERRING_MD = "REFERRING_MD"
    SELF = "SELF"
    OTHER = "OTHER"
    _UNKNOWN = "__REFERRALSOURCE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ReferralSource":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        hospital: typing.Callable[[], T_Result],
        referring_md: typing.Callable[[], T_Result],
        self_: typing.Callable[[], T_Result],
        other: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ReferralSource.HOSPITAL:
            return hospital()
        if self is ReferralSource.REFERRING_MD:
            return referring_md()
        if self is ReferralSource.SELF:
            return self_()
        if self is ReferralSource.OTHER:
            return other()
        return _unknown_member(self._value_)
