# This file was auto-generated by Fern from our API Definition.

import typing

from ....core import enum

T_Result = typing.TypeVar("T_Result")


class Gender(enum.StrEnum):
    MALE = "male"
    FEMALE = "female"
    OTHER = "other"
    NOT_GIVEN = "not_given"
    UNKNOWN = "unknown"
    _UNKNOWN = "__GENDER_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "Gender":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        male: typing.Callable[[], T_Result],
        female: typing.Callable[[], T_Result],
        other: typing.Callable[[], T_Result],
        not_given: typing.Callable[[], T_Result],
        unknown: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is Gender.MALE:
            return male()
        if self is Gender.FEMALE:
            return female()
        if self is Gender.OTHER:
            return other()
        if self is Gender.NOT_GIVEN:
            return not_given()
        if self is Gender.UNKNOWN:
            return unknown()
        return _unknown_member(self._value_)
