# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AuthGetTokenResponse(UniversalBaseModel):
    """
    Examples
    --------
    from candid.resources.auth.resources.default import AuthGetTokenResponse

    AuthGetTokenResponse(
        access_token="eyJz93a...k4laUWw",
        expires_in=86400,
        token_type="Bearer",
    )
    """

    access_token: str
    expires_in: int = pydantic.Field()
    """
    Time in seconds.
    """

    token_type: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
