# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .health_care_code_information import HealthCareCodeInformation
from .treatment_code import TreatmentCode
from .treatment_code_qualifier import TreatmentCodeQualifier


class TreatmentCodeInformation(HealthCareCodeInformation):
    """
    This corresponds to the TC code qualifier value.
    """

    treatment_code_qualifier: TreatmentCodeQualifier
    treatment_code: TreatmentCode

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
