# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .service_line_create_base_base import ServiceLineCreateBaseBase


class UniversalServiceLineCreate(ServiceLineCreateBaseBase):
    diagnosis_pointers: typing.Optional[typing.List[int]] = pydantic.Field(default=None)
    """
    Indices (zero-indexed) of all the diagnoses this service line references
    """

    revenue_code: typing.Optional[str] = pydantic.Field(default=None)
    """
    A 4 digit code that specifies facility department or type of service arrangement for institutional service line items (837i). This code is not required for professional claim billing (837p).
    """

    procedure_code: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
