# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class ContractType(enum.StrEnum):
    PROFESSIONAL = "professional"
    """
    Professional contract
    """

    INSTITUTIONAL = "institutional"
    """
    Institutional contract
    """

    _UNKNOWN = "__CONTRACTTYPE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ContractType":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        professional: typing.Callable[[], T_Result],
        institutional: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ContractType.PROFESSIONAL:
            return professional()
        if self is ContractType.INSTITUTIONAL:
            return institutional()
        return _unknown_member(self._value_)
