# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .phone_number_type import PhoneNumberType


class PhoneNumberOptional(UniversalBaseModel):
    """
    Examples
    --------
    from candid.resources.commons import PhoneNumberOptional, PhoneNumberType

    PhoneNumberOptional(
        number="1234567890",
        type=PhoneNumberType.HOME,
    )
    """

    number: typing.Optional[str] = None
    type: typing.Optional[PhoneNumberType] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
