# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .admitting_diagnosis_code_qualifier import AdmittingDiagnosisCodeQualifier
from .health_care_code_information import HealthCareCodeInformation
from .icd_code import IcdCode


class AdmittingDiagnosis(HealthCareCodeInformation):
    """
    This corresponds to BJ or ABJ code qualifier values.
    """

    admitting_diagnosis_code_qualifier: AdmittingDiagnosisCodeQualifier
    admitting_diagnosis_code: IcdCode

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
