# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....common.types.payer_id import PayerId
from .....common.types.payer_plan_group_id import PayerPlanGroupId
from .network_type import NetworkType


class PayerPlanGroupFields(UniversalBaseModel):
    payer_plan_group_id: PayerPlanGroupId
    payer_id: PayerId
    payer_name: str
    plan_type: NetworkType

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
