# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class TestResultType(enum.StrEnum):
    HEMATOCRIT = "HEMATOCRIT"
    HEMOGLOBIN = "HEMOGLOBIN"
    LDL = "LDL"
    VITAMIN_D = "VITAMIN_D"
    _UNKNOWN = "__TESTRESULTTYPE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "TestResultType":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        hematocrit: typing.Callable[[], T_Result],
        hemoglobin: typing.Callable[[], T_Result],
        ldl: typing.Callable[[], T_Result],
        vitamin_d: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is TestResultType.HEMATOCRIT:
            return hematocrit()
        if self is TestResultType.HEMOGLOBIN:
            return hemoglobin()
        if self is TestResultType.LDL:
            return ldl()
        if self is TestResultType.VITAMIN_D:
            return vitamin_d()
        return _unknown_member(self._value_)
