# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .universal_encounter_create import UniversalEncounterCreate
    from .universal_encounter_create_base import UniversalEncounterCreateBase
    from .universal_encounter_create_from_pre_encounter import UniversalEncounterCreateFromPreEncounter
    from .universal_encounter_create_from_pre_encounter_base import UniversalEncounterCreateFromPreEncounterBase
    from .universal_encounter_update import UniversalEncounterUpdate
    from .universal_encounter_update_base import UniversalEncounterUpdateBase
_dynamic_imports: typing.Dict[str, str] = {
    "UniversalEncounterCreate": ".universal_encounter_create",
    "UniversalEncounterCreateBase": ".universal_encounter_create_base",
    "UniversalEncounterCreateFromPreEncounter": ".universal_encounter_create_from_pre_encounter",
    "UniversalEncounterCreateFromPreEncounterBase": ".universal_encounter_create_from_pre_encounter_base",
    "UniversalEncounterUpdate": ".universal_encounter_update",
    "UniversalEncounterUpdateBase": ".universal_encounter_update_base",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "UniversalEncounterCreate",
    "UniversalEncounterCreateBase",
    "UniversalEncounterCreateFromPreEncounter",
    "UniversalEncounterCreateFromPreEncounterBase",
    "UniversalEncounterUpdate",
    "UniversalEncounterUpdateBase",
]
