# This file was auto-generated by Fern from our API Definition.

import typing
import uuid

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .contract_base import ContractBase
from .contract_type import ContractType
from .contracting_provider_id import ContractingProviderId


class ContractCreate(ContractBase):
    contract_type: ContractType = pydantic.Field()
    """
    The type of contract
    """

    contracting_provider_id: ContractingProviderId = pydantic.Field()
    """
    The UUID of the provider under agreement to the contract
    """

    payer_uuid: uuid.UUID = pydantic.Field()
    """
    The UUID of the insurance company under agreement to the contract
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
