# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .diagnosis_related_group_code_qualifier import DiagnosisRelatedGroupCodeQualifier
from .health_care_code_information import HealthCareCodeInformation
from .msdrg_code import MsdrgCode


class DiagnosisRelatedGroup(HealthCareCodeInformation):
    """
    This corresponds to DR code qualifier values.
    """

    diagnosis_related_group_code_qualifier: DiagnosisRelatedGroupCodeQualifier
    diagnosis_related_group_code: MsdrgCode

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
