# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....coverages.resources.v_1.types.coverage import Coverage
from .patient import Patient


class PatientCoverageSnapshot(UniversalBaseModel):
    patient: Patient
    primary_coverage: typing.Optional[Coverage] = None
    secondary_coverage: typing.Optional[Coverage] = None
    tertiary_coverage: typing.Optional[Coverage] = None
    coverages_for_related_causes: typing.List[Coverage]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
