# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .organization_service_facility import OrganizationServiceFacility
    from .organization_service_facility_create import OrganizationServiceFacilityCreate
    from .organization_service_facility_id import OrganizationServiceFacilityId
    from .organization_service_facility_page import OrganizationServiceFacilityPage
    from .organization_service_facility_update import OrganizationServiceFacilityUpdate
    from .service_facility_mode import ServiceFacilityMode
    from .service_facility_operational_status import ServiceFacilityOperationalStatus
    from .service_facility_physical_type import ServiceFacilityPhysicalType
    from .service_facility_status import ServiceFacilityStatus
    from .service_facility_type import ServiceFacilityType
_dynamic_imports: typing.Dict[str, str] = {
    "OrganizationServiceFacility": ".organization_service_facility",
    "OrganizationServiceFacilityCreate": ".organization_service_facility_create",
    "OrganizationServiceFacilityId": ".organization_service_facility_id",
    "OrganizationServiceFacilityPage": ".organization_service_facility_page",
    "OrganizationServiceFacilityUpdate": ".organization_service_facility_update",
    "ServiceFacilityMode": ".service_facility_mode",
    "ServiceFacilityOperationalStatus": ".service_facility_operational_status",
    "ServiceFacilityPhysicalType": ".service_facility_physical_type",
    "ServiceFacilityStatus": ".service_facility_status",
    "ServiceFacilityType": ".service_facility_type",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "OrganizationServiceFacility",
    "OrganizationServiceFacilityCreate",
    "OrganizationServiceFacilityId",
    "OrganizationServiceFacilityPage",
    "OrganizationServiceFacilityUpdate",
    "ServiceFacilityMode",
    "ServiceFacilityOperationalStatus",
    "ServiceFacilityPhysicalType",
    "ServiceFacilityStatus",
    "ServiceFacilityType",
]
