# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class ValueCode(enum.StrEnum):
    C_01_MONEY = "01"
    """
    Most Common Semi-private Rate
    To provide for the recording of hospital’s most common semi-private rate.
    """

    C_02_MONEY = "02"
    """
    Hospital has no Semi-private Rooms
    Entering this code requires $0.00 amount.
    """

    C_04_MONEY = "04"
    """
    Professional Component Charges which are Combined Billed
    Code indicates the amount shown is the sum of technical and professional charges, which are combined billed. Medicare uses this information in internal processes and in the CMS notice of utilization sent to the patient to explain that Part B coinsurance applies to the professional component.
    """

    C_05_MONEY = "05"
    """
    Professional Component Included in Charges and also Billed Separate to Carrier
    Amount shown is the combined billed charges (technical and professional); however the provider is submitting a separate professional bill to the health plan. For use on Medicare or TRICARE bills and all Medicaid bills if state specifies need for this information.
    """

    C_06_MONEY = "06"
    """
    Blood Deductible
    Total cash blood deductible. If appropriate, enter Medicare Part A or Part B blood deductible amount. (To report other than the blood deductible, that is to report the program deductible, see Value Codes (FL39-FL41) A1, B1, and C1.)
    """

    C_08_MONEY = "08"
    """
    Life Time Reserve Amount in the First Calendar Year
    Lifetime reserve amount charged in the year of admission. Note: For Medicare, use this code only for Part A bills. For Part B Coinsurance use Value Codes (FL39-41) A2, B2, and C2).
    """

    C_09_MONEY = "09"
    """
    Coinsurance Amount in the First Calendar Year
    Coinsurance amounts, charged in the year of admission.
    """

    C_10_MONEY = "10"
    """
    Lifetime Reserve Amount in the Second Calendar Year
    Lifetime reserve amount charged in the year of discharge where the bill spans two calendar years.
    """

    C_11_MONEY = "11"
    """
    Coinsurance Amount in the Second Calendar Year
    Coinsurance amount charged in the year of discharge where the inpatient bill spans two calendar years.
    """

    C_12_MONEY = "12"
    """
    Working Aged Beneficiary/Spouse with Employer Group Health Plan
    Amount shown reflects that portion of a payment from a higher priority employer group health insurance made on behalf of an aged beneficiary. For Medicare purposes the provider is billing Medicare as the secondary, payer (based on MSP development) for covered services on this bill.
    """

    C_13_MONEY = "13"
    """
    ESRD Beneficiary in a Medicare Coordination Period with an Employer Group Health Plan
    Amount shown is that portion of a payment from a higher priority employer group health insurance payment made on behalf of an ESRD beneficiary that the provider is applying to Medicare covered services on this bill.
    """

    C_14_MONEY = "14"
    """
    No-Fault, Including Auto/Other
    Amount shown is that portion from a higher priority no-fault insurance, including auto/other made on behalf of the patient or insured. For Medicare beneficiaries, the provider should apply this amount to the Medicare covered services on this bill.
    """

    C_15_MONEY = "15"
    """
    Worker’s Compensation
    Amount shown is that portion of a payment from a higher priority worker’s compensation insurance made on behalf of the patient or insured. For Medicare beneficiaries the provider should apply this amount to Medicare covered services on this bill.
    """

    C_16_MONEY = "16"
    """
    PHS, or Other Federal Agency
    Amount shown is that portion of a payment from a higher priority Public Health Service or the Federal Agency made on behalf of a Medicare beneficiary that the provider is applying to Medicare covered services on this bill.
    """

    C_21_MONEY = "21"
    """
    Catastrophic
    Catastrophic Medicaid-eligibility and coverage requirements determined at the state level.
    """

    C_22_MONEY = "22"
    """
    Surplus Income
    Surplus (or excess) income as designated by Medicaid eligibility requirements determined at the state level.
    """

    C_23_MONEY = "23"
    """
    Recurring Monthly Income
    Monthly income as designated by Medicaid-eligibility requirements determined at the state level.
    """

    C_24_NUM = "24"
    """
    Medicaid Rate Code
    Code indicating the payment or reimbursement rate designated by Medicaid at the state level.
    """

    C_25_MONEY = "25"
    """
    Offset to the Patient-Payment Amount - Prescription Drugs
    Prescription drugs paid for out of a long-term care facility resident/patient’s funds in the billing period submitted (Statement Covers Period).
    """

    C_26_MONEY = "26"
    """
    Offset to the Patient-Payment Amount - Hearing and Ear Services
    Hearing and ear services paid for out of a long-term care facility resident/patient’s funds in the billing period submitted (Statement Covers Period).
    """

    C_27_MONEY = "27"
    """
    Offset to the Patient-Payment Amount - Vision and Eye Services
    Vision and eye services paid for out of a long-term care facility resident/patient’s funds in the billing period submitted (Statement Covers Period).
    """

    C_28_MONEY = "28"
    """
    Offset to the Patient-Payment Amount - Dental Services
    Dental services paid for out of a long-term care facility resident/patient’s funds in the billing period submitted (Statement Covers Period).
    """

    C_29_MONEY = "29"
    """
    Offset to the Patient-Payment Amount - Chiropractic Services
    Chiropractic services paid for out of a long-term care facility resident/patient’s funds in the billing period submitted (Statement Covers Period).
    """

    C_30_MONEY = "30"
    """
    Preadmission Testing
    This code reflects charges for preadmission outpatient diagnostic services in preparation for a previously scheduled admission.
    """

    C_31_MONEY = "31"
    """
    Patient Liability Amount
    Approved amount to charge the beneficiary for non-covered accommodations, diagnostic procedures or treatments.
    """

    C_32_NUM = "32"
    """
    Multiple Patient Ambulance Transport
    When more than one patient is transported in a single ambulance trip, report the total number of patients transported.
    """

    C_33_MONEY = "33"
    """
    Offset to the Patient-Payment Amount - Podiatric Services
    Podiatric services paid for out of a long-term care facility resident/patient’s funds in the billing period submitted (Statement Covers Period).
    """

    C_34_MONEY = "34"
    """
    Offset to the Patient-Payment Amount - Other Medical Services
    Other medical services paid for out of a long-term care facility resident/patient’s funds in the billing period submitted (Statement Covers Period).
    """

    C_35_MONEY = "35"
    """
    Offset to the Patient-Payment Amount - Health Insurance Premiums
    Health insurance premiums paid for out of long-term care facility resident/patient’s funds in the billing period submitted (Statement Covers Period).
    """

    C_37_NUM = "37"
    """
    Units of Blood Furnished
    The total number of units of whole blood or packed red cells furnished to the patient, regardless of whether the hospital charges for blood or not.
    """

    C_38_NUM = "38"
    """
    Blood Deductible Units
    The number of unreplaced deductible units of packed red cells furnished for which the patient is responsible. If all deductible units furnished have been replaced, no entry is made.
    """

    C_39_NUM = "39"
    """
    Units of Blood Replaced
    The total number of units of whole blood or packed red cells furnished to the patient that have been replaced by or on behalf of the patient.
    """

    C_40_MONEY = "40"
    """
    New Coverage not Implemented by HMO (for inpatient service only)
    Amount shown is for inpatient charges covered by the HMO. (Use this code when the bill includes inpatient charges for newly covered services that are not paid by the HMO.) Note: Condition Codes 04 and 78 should also be reported.
    """

    C_41_MONEY = "41"
    """
    Black Lung
    Code indicates the amount shown is that portion of a higher priority Black Lung (federal program) payment made on behalf of a Medicare beneficiary. Note: The reporting of zero indicates the provider is claiming a conditional payment because there has been a substantial delay in payment from the Black Lung Program.
    """

    C_42_MONEY = "42"
    """
    VA or PACE
    Code indicates the amount shown is that portion of a higher priority VA or PACE payment made on behalf of a Medicare beneficiary and that you are applying to Medicare as secondary payer for covered Medicare services on this claim.
    """

    C_43_MONEY = "43"
    """
    Disabled Beneficiary Under Age 65 with LGHP
    Code indicates the amount shown is that portion of a higher priority LGHP payment made on behalf of a disabled beneficiary that you are applying to covered Medicare charges on this bill.
    """

    C_44_MONEY = "44"
    """
    Amount Provider Agreed to Accept from Primary Payer when this Amount is less than Charges but Higher than Payment Received
    Report the amount the provider was obligated to accept from a primary payer when the amount is less than charges but higher than or equal to the payment received. Secondary payment may be due. Note: The following value codes report the actual amounts paid: 12- 16, 41-43, and 47. Value Code 44 should always be equal to, or, greater than the amounts indicated in the value codes indicated immediately above.
    """

    C_45_NUM = "45"
    """
    Accident Hour
    The hour when the accident occurred that necessitated medical treatment. 00 12:00 - 12:59 (Midnight), 13 01:00 - 01:59, 01 01:00 - 01:59, 14 02:00 - 02:59, 02 02:00 - 02:59, 15 03:00 - 03:59, 03 03:00 - 03:59, 16 04:00 - 04:59, 04 04:00 - 04:59, 17 05:00 - 05:59, 05 05:00 - 05:59, 18 06:00 - 06:59, 06 06:00 - 06:59, 19 07:00 - 07:59, 07 07:00 - 07:59, 20 08:00 - 08:59, 08 08:00 - 08:59, 21 09:00 - 09:59, 09 09:00 - 09:59, 22 10:00 - 10:59, 10 10:00 - 10:59, 23 11:00 - 11:59, 11 11:00 - 11:59, 99 Unknown, 12 12:00 - 12:59 (Noon)
    """

    C_46_NUM = "46"
    """
    Number of Grace Days
    Follows the QIO determination. This is the number of days determined by the QIO (medical necessity reviewer) as necessary to arrange for the patient’s post-discharge care.
    """

    C_47_MONEY = "47"
    """
    Any Liability Insurance
    Amount shown is that portion from a higher priority liability insurance made on behalf of a Medicare beneficiary that the provider is applying to Medicare covered services on this bill. Enter zero in the amount field if you are claiming a conditional payment.
    """

    C_48_NUM = "48"
    """
    Hemoglobin Reading
    The most recent hemoglobin reading taken before the start of this billing period. For patients just starting, use the most recent value prior to the onset if treatment. The reading is a 3-byte numeric element (XX.X). Results exceeding 3-position numeric elements (e.g., 10.50) are reported as 10.5.
    """

    C_49_NUM = "49"
    """
    Hematocrit Reading
    The most recent hematocrit reading taken before the start of this billing period. For patients just starting, use the most recent value prior to the onset if treatment. The reading is a 3-byte numeric element (XX.X). Results exceeding 3-position numeric elements (e.g., l0.50) are reported as 10.5.
    """

    C_50_NUM = "50"
    """
    Physical Therapy Visits
    Report the number of physical therapy visits provided from the onset of treatment from this billing provider through this billing period.
    """

    C_51_NUM = "51"
    """
    Occupational Therapy Visits
    Report the number of occupational therapy visits provided from the onset of treatment from this billing provider) through this billing period.
    """

    C_52_NUM = "52"
    """
    Speech Therapy Visits
    Report the number of speech therapy visits provided from the onset of treatment by this billing provider through this period.
    """

    C_53_NUM = "53"
    """
    Cardiac Rehab Visits
    The number of cardiac rehabilitation visits from the onset of treatment from the billing provider through this billing period.
    """

    C_54_NUM = "54"
    """
    Newborn Birth Weight in Grams
    Actual birth weight or weight at time of admission for an extramural birth. Required on all claims with Priority (Type) of Admission of 4 and on other claims as required by state law.
    """

    C_55_MONEY = "55"
    """
    Eligibility Threshold for Charity Care
    The amount at which a health care facility determines the eligibility threshold for charity care.
    """

    C_56_NUM = "56"
    """
    Skilled Nurse - Home Visit Hours (HHA only)
    The number of home visit hours of skilled nursing provided during the billing period. Count only hours spent in the home.  Exclude travel time. Report in whole hours, rounded to the nearest whole hour.
    """

    C_57_NUM = "57"
    """
    Home Health Aide - Home Visit Hours (HHA only)
    The number of hours of home health aide services provided during the billing period.  Count only hours spent in the home. Exclude travel time. Report in whole hours, rounded to the nearest whole hour.
    """

    C_58_NUM = "58"
    """
    Arterial Blood Gas (P02)
    Arterial blood gas value at beginning of each reporting period for oxygen therapy. This value or the value in Value Code 59 will be required on the initial bill for oxygen therapy and on the fourth month’s bill.  Report two digits rounded to the nearest whole number. Example: A value of 56.5 should be reported as 57.
    """

    C_59_NUM = "59"
    """
    Oxygen Saturation Oximetry
    Oxygen percent saturation at the beginning of each reporting period for oxygen therapy. This value or the value in Value Code 58 will be required on the initial bill for oxygen therapy and on the fourth month’s bill.  Report two digits rounded to the nearest whole percent. Example: 93.5 percent should be reported as 0.94. A value of 100 percent would be reported as 1.
    """

    C_60_NUM = "60"
    """
    HHA Branch MSA
    MSA in which HHA branch is located (Report MSA when branch location is different than the HHA’s.
    """

    C_61_NUM = "61"
    """
    Place of Residence where Service is Furnished (HHA and Hospice)
    MSA or Core Based Statistical Area (CBSA) number (or rural state code) of the place of residence where the home health or hospice service is delivered.
    """

    C_66_MONEY = "66"
    """
    Medicaid Spend Down Amount
    The dollar amount that was used to meet the recipient’s spend down liability for this claim.
    """

    C_67_NUM = "67"
    """
    Peritoneal Dialysis
    The number of hours of peritoneal dialysis provided during the billing period.  Count only the hours spent in the home. Exclude travel time. Report in whole hours, rounded to the nearest whole hour.
    """

    C_68_NUM = "68"
    """
    EPO-Drug
    Number of units of EPO administered and/or supplied relating to the billing period. Report amount in whole units.
    """

    C_69_NUM = "69"
    """
    State Charity Care Percent
    Code indicates the percentage of charity care eligibility for the patient.  For example, a rate of 10.5% is shown as: 0 . 1 0 5
    """

    C_80_NUM = "80"
    """
    Covered Days
    The number of days covered by the primary payer as qualified by the payer.
    """

    C_81_NUM = "81"
    """
    Non-covered Days
    Days of care not covered by the primary payer.
    """

    C_82_NUM = "82"
    """
    Co-insurance Days
    The inpatient Medicare days occurring after the 60th day and before the 91st day or inpatient SNF/Swing Bed days occurring after the 20th and before the 101st day in a single spell of illness.
    """

    C_83_NUM = "83"
    """
    Lifetime Reserve Days
    Under Medicare, each beneficiary has a lifetime reserve of 60 additional days of inpatient hospital services after using 90 days of inpatient hospital services during a spell of illness.
    """

    C_84_NUM = "84"
    """
    Shorter Duration Hemodialysis
    The number of sessions per week as specified in the patient’s plan of care for hemodialysis that is shorter in duration (Revenue Code 0826) than conventional sessions (reported under Revenue Code 0821).
    """

    C_85_NUM = "85"
    """
    County where Service is Rendered (Effective 1/1/19)
    Report the Federal Information Processing Standards (FIPS) state and county codes when required by law or regulation with no space between the state code and the county code.
    """

    C_87_MONEY = "87"
    """
    Gene Therapy Invoice Cost (Effective 4/1/20)
    Invoice/acquisition cost of modified biologics. For use with Revenue Category 0892.
    """

    C_89_MONEY = "89"
    """
    Allogeneic Stem Cell Transplant – Total All-inclusive Donor Charges (Effective 7/1/20)
    Report on the recipient’s stem cell transplant claim the total of all donor charges, including charges billed on separately submitted claims.
    """

    C_90_MONEY = "90"
    """
    Cell Therapy Invoice Cost (Effective 4/1/20)
    Invoice/acquisition cost of modified biologics. For use with Revenue Category 0891.
    """

    C_91_MONEY = "91"
    """
    Charges for Kidney Acquisition (Effective 10/1/21)
    Used by providers to identify charges for kidney acquisitions when mandated by state or federal law or regulation.
    """

    CA_0_NUM = "A0"
    """
    Special ZIP Code Reporting
    Five digit ZIP Code of the location from which the beneficiary is initially placed on board the ambulance.
    """

    CA_1_MONEY = "A1"
    """
    Deductible Payer A
    The amount assumed by the provider to be applied to the patient’s policy/program deductible amount involving the indicated payer. (Note: Report Medicare blood deductibles under Value Code 6.)
    """

    CA_2_MONEY = "A2"
    """
    Coinsurance Payer A
    The amount assumed by the provider to be applied toward the patient’s coinsurance amount involving the indicated payer. (Note: For Medicare, use this code only for reporting Part B coinsurance amounts. For Part A coinsurance amounts use Value Codes 8-11.)
    """

    CA_3_MONEY = "A3"
    """
    Estimated Responsibility Payer A
    The amount estimated by the provider to be paid by the indicated payer; it is not the actual payment.
    """

    CA_4_MONEY = "A4"
    """
    Covered Self-administrable Drugs - Emergency
    The covered charge amount for self-administrable drugs administered to the patient in an emergency situation (e.g., diabetic coma). For use with Revenue Code 0637.
    """

    CA_5_MONEY = "A5"
    """
    Covered Self-administrable Drugs - not Self-administrable in the Form and Situation Furnished to Patient
    The amount included in covered charges for self-administrable drugs administered to the patient because the drug was not self-administrable in the form and situation in which it was furnished to the patient. For use with Revenue Code 0637.
    """

    CA_6_MONEY = "A6"
    """
    Covered Self-administrable Drugs - Diagnostic Study and Other
    The amount included in covered charges for self-administrable drugs administered to the patient because the drug was necessary for diagnostic study or other reason (e.g., the drug is specifically covered by the payer).
    """

    CA_7_MONEY = "A7"
    """
    Co-payment Payer A
    The amount assumed by the provider to be applied toward the patient’s co-payment amount involving the indicated payer.
    """

    CA_8_NUM = "A8"
    """
    Patient Weight
    Weight of patient in kilograms. Report this data only when the health plan has a predefined change in reimbursement that is affected by weight. For newborns, use Value Code 54
    """

    CA_9_NUM = "A9"
    """
    Patient Height
    Height of patient in centimeters. Report this data only when the health plan has a predefined change in reimbursement that is affected by height.
    """

    CAA_MONEY = "AA"
    """
    Regulatory Surcharges, Assessments, Allowances or Health Care Related Taxes Payer A
    The amount of regulatory surcharges, assessments, allowances or health care related taxes pertaining to the indicated payer.
    """

    CAB_MONEY = "AB"
    """
    Other Assessments or Allowances (e.g., Medical Education) Payer A
    The amount of other assessments or allowances (e.g., medical education) pertaining to the indicated payer.
    """

    CB_1_MONEY = "B1"
    """
    Deductible Payer B
    The amount assumed by the provider to be applied to the patient’s policy/program deductible amount involving the indicated payer. (Note: Medicare blood deductibles should be reported under Value Code 6.)
    """

    CB_2_MONEY = "B2"
    """
    Coinsurance Payer B
    The amount assumed by the provider to be applied toward the patient’s coinsurance amount involving the indicated payer. For Part A coinsurance amounts use Value Codes 8-11.)
    """

    CB_3_MONEY = "B3"
    """
    Estimated Responsibility Payer B
    The amount estimated by the provider to be paid by the indicated payer; it is not the actual payment.
    """

    CB_7_MONEY = "B7"
    """
    Co-payment Payer B
    The amount assumed by the provider to be applied toward the patient’s co-payment amount involving the indicated payer.
    """

    CBA_MONEY = "BA"
    """
    Regulatory Surcharges, Assessments, Allowances or Health Care Related Taxes Payer B
    The amount of regulatory surcharges, assessments, allowances or health care related taxes pertaining to the indicated payer.
    """

    CBB_MONEY = "BB"
    """
    Other Assessments or Allowances (e.g., Medical Education) Payer B
    The amount of other assessments or allowances (e.g., medical education) pertaining to the indicated payer.
    """

    CC_1_MONEY = "C1"
    """
    Deductible Payer C
    The amount assumed by the provider to be applied to the patient’s policy/program deductible amount involving the indicated payer. (Note: Medicare blood deductibles should be reported under Value Code 6.)
    """

    CC_2_MONEY = "C2"
    """
    Coinsurance Payer C
    The amount assumed by the provider to be applied toward the patient’s coinsurance amount involving the indicated payer. For Part A coinsurance amounts use Value Codes 8-11.)
    """

    CC_3_MONEY = "C3"
    """
    Estimated Responsibility Payer C
    The amount estimated by the provider to be paid by the indicated payer; it is not the actual payment.
    """

    CC_7_MONEY = "C7"
    """
    Co-payment Payer C
    The amount assumed by the provider to be applied toward the patient’s co-payment amount involving the indicated payer.
    """

    CCA_MONEY = "CA"
    """
    Regulatory Surcharges, Assessments, Allowances or Health Care Related Taxes Payer C
    The amount of regulatory surcharges, assessments, allowances or health care related taxes pertaining to the indicated payer.
    """

    CCB_MONEY = "CB"
    """
    Other Assessments or Allowances (e.g., Medical Education) Payer C
    The amount of other assessments or allowances (e.g., medical education) pertaining to the indicated payer.
    """

    CD_3_MONEY = "D3"
    """
    Patient Estimated Responsibility
    The amount estimated by the provider to be paid by the indicated patient.
    """

    CD_4_NUM = "D4"
    """
    Clinical Trial Number Assigned by NLM/NIH
    8-digit, numeric National Library of Medicine/ National Institutes of Health assigned clinical trial number.
    """

    CD_5_NUM = "D5"
    """
    Last Kt/V Reading (Effective 7/1/10)
    Result of last Kt/V reading. For in-center hemodialysis patients, this is the last reading taken during the billing period. For peritoneal dialysis patients (and home hemodialysis patients), this may be before the current billing period but should be within 4 months of the date of service.
    """

    CD_6_NUM = "D6"
    """
    Total Number of Minutes of Dialysis Provided During the Billing Period. (Effective 1/1/21)
    The machine reported number of minutes (rounded to the nearest whole minute) of dialysis treatment time.  The total count includes only the minutes spent dialyzing. The duration begins when the treatment starts and ends when the treatment is complete. The units reported must exceed 1.  For Medicare ESRD claims. See Medicare manual for further instructions on the use of this code along with other related UB codes.
    """

    CFC_MONEY = "FC"
    """
    Patient Paid Amount
    The amount the provider has received from the patient toward payment of this bill. (Effective 7/1/08)
    """

    CFD_MONEY = "FD"
    """
    Credit Received from the Manufacturer for a Medical Device
    The amount the provider has received from a medical device manufacturer as credit for a medical device. (Effective 7/1/15)
    """

    CG_8_NUM = "G8"
    """
    Facility where Inpatient Hospice Service is Delivered
    MSA or Core Based Statistical Area (CBSA) number (or rural state code) of the facility where inpatient hospice service is delivered.
    """

    CP_1_NUM = "P1"
    """
    Heart Rate (Effective 7/1/19)
    FOR PUBLIC HEALTH DATAREPORTING ONLY when required by state or federal law or regulations. Code indicates patient heart rate in beats per minute taken upon arrival for treatment.
    """

    CP_2_NUM = "P2"
    """
    Blood Pressure – Systolic (Effective 7/1/19)
    FOR PUBLIC HEALTH DATA REPORTING ONLY when required by state or federal law or regulations. Code indicates patient systolic blood pressure in mg/dl, taken upon arrival for treatment.
    """

    CP_3_NUM = "P3"
    """
    Blood Pressure – Diastolic (Effective 7/1/19)
    FOR PUBLIC HEALTH DATAREPORTING ONLY when required by state or federal law or regulations. Code indicates patient diastolic blood pressure in mg/dl, taken upon arrival for treatment.
    """

    CY_1_MONEY = "Y1"
    """
    Part A Demonstration Payment
    This is the portion of the payment designated as reimbursement for Part A services under the demonstration/model.
    """

    CY_2_MONEY = "Y2"
    """
    Part B Demonstration Payment
    This is the portion of the payment designated as reimbursement for Part B services under the demonstration/model. No deductible or coinsurance has been applied.
    """

    CY_3_MONEY = "Y3"
    """
    Part B Coinsurance
    This is the amount of Part B coinsurance applied by the A/B MAC to this demonstration/model claim.
    """

    CY_4_MONEY = "Y4"
    """
    Conventional Provider Payment
    This is the amount Medicare would have reimbursed the provider for Part A services if there had been no demonstration/model.
    """

    CY_5_MONEY = "Y5"
    """
    Part B Deductible (Effective 4/1/13)
    This is the amount of Part B deductible applied by the A/B MAC to this demonstration/model claim.
    """

    _UNKNOWN = "__VALUECODE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ValueCode":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        c_01_money: typing.Callable[[], T_Result],
        c_02_money: typing.Callable[[], T_Result],
        c_04_money: typing.Callable[[], T_Result],
        c_05_money: typing.Callable[[], T_Result],
        c_06_money: typing.Callable[[], T_Result],
        c_08_money: typing.Callable[[], T_Result],
        c_09_money: typing.Callable[[], T_Result],
        c_10_money: typing.Callable[[], T_Result],
        c_11_money: typing.Callable[[], T_Result],
        c_12_money: typing.Callable[[], T_Result],
        c_13_money: typing.Callable[[], T_Result],
        c_14_money: typing.Callable[[], T_Result],
        c_15_money: typing.Callable[[], T_Result],
        c_16_money: typing.Callable[[], T_Result],
        c_21_money: typing.Callable[[], T_Result],
        c_22_money: typing.Callable[[], T_Result],
        c_23_money: typing.Callable[[], T_Result],
        c_24_num: typing.Callable[[], T_Result],
        c_25_money: typing.Callable[[], T_Result],
        c_26_money: typing.Callable[[], T_Result],
        c_27_money: typing.Callable[[], T_Result],
        c_28_money: typing.Callable[[], T_Result],
        c_29_money: typing.Callable[[], T_Result],
        c_30_money: typing.Callable[[], T_Result],
        c_31_money: typing.Callable[[], T_Result],
        c_32_num: typing.Callable[[], T_Result],
        c_33_money: typing.Callable[[], T_Result],
        c_34_money: typing.Callable[[], T_Result],
        c_35_money: typing.Callable[[], T_Result],
        c_37_num: typing.Callable[[], T_Result],
        c_38_num: typing.Callable[[], T_Result],
        c_39_num: typing.Callable[[], T_Result],
        c_40_money: typing.Callable[[], T_Result],
        c_41_money: typing.Callable[[], T_Result],
        c_42_money: typing.Callable[[], T_Result],
        c_43_money: typing.Callable[[], T_Result],
        c_44_money: typing.Callable[[], T_Result],
        c_45_num: typing.Callable[[], T_Result],
        c_46_num: typing.Callable[[], T_Result],
        c_47_money: typing.Callable[[], T_Result],
        c_48_num: typing.Callable[[], T_Result],
        c_49_num: typing.Callable[[], T_Result],
        c_50_num: typing.Callable[[], T_Result],
        c_51_num: typing.Callable[[], T_Result],
        c_52_num: typing.Callable[[], T_Result],
        c_53_num: typing.Callable[[], T_Result],
        c_54_num: typing.Callable[[], T_Result],
        c_55_money: typing.Callable[[], T_Result],
        c_56_num: typing.Callable[[], T_Result],
        c_57_num: typing.Callable[[], T_Result],
        c_58_num: typing.Callable[[], T_Result],
        c_59_num: typing.Callable[[], T_Result],
        c_60_num: typing.Callable[[], T_Result],
        c_61_num: typing.Callable[[], T_Result],
        c_66_money: typing.Callable[[], T_Result],
        c_67_num: typing.Callable[[], T_Result],
        c_68_num: typing.Callable[[], T_Result],
        c_69_num: typing.Callable[[], T_Result],
        c_80_num: typing.Callable[[], T_Result],
        c_81_num: typing.Callable[[], T_Result],
        c_82_num: typing.Callable[[], T_Result],
        c_83_num: typing.Callable[[], T_Result],
        c_84_num: typing.Callable[[], T_Result],
        c_85_num: typing.Callable[[], T_Result],
        c_87_money: typing.Callable[[], T_Result],
        c_89_money: typing.Callable[[], T_Result],
        c_90_money: typing.Callable[[], T_Result],
        c_91_money: typing.Callable[[], T_Result],
        ca_0_num: typing.Callable[[], T_Result],
        ca_1_money: typing.Callable[[], T_Result],
        ca_2_money: typing.Callable[[], T_Result],
        ca_3_money: typing.Callable[[], T_Result],
        ca_4_money: typing.Callable[[], T_Result],
        ca_5_money: typing.Callable[[], T_Result],
        ca_6_money: typing.Callable[[], T_Result],
        ca_7_money: typing.Callable[[], T_Result],
        ca_8_num: typing.Callable[[], T_Result],
        ca_9_num: typing.Callable[[], T_Result],
        caa_money: typing.Callable[[], T_Result],
        cab_money: typing.Callable[[], T_Result],
        cb_1_money: typing.Callable[[], T_Result],
        cb_2_money: typing.Callable[[], T_Result],
        cb_3_money: typing.Callable[[], T_Result],
        cb_7_money: typing.Callable[[], T_Result],
        cba_money: typing.Callable[[], T_Result],
        cbb_money: typing.Callable[[], T_Result],
        cc_1_money: typing.Callable[[], T_Result],
        cc_2_money: typing.Callable[[], T_Result],
        cc_3_money: typing.Callable[[], T_Result],
        cc_7_money: typing.Callable[[], T_Result],
        cca_money: typing.Callable[[], T_Result],
        ccb_money: typing.Callable[[], T_Result],
        cd_3_money: typing.Callable[[], T_Result],
        cd_4_num: typing.Callable[[], T_Result],
        cd_5_num: typing.Callable[[], T_Result],
        cd_6_num: typing.Callable[[], T_Result],
        cfc_money: typing.Callable[[], T_Result],
        cfd_money: typing.Callable[[], T_Result],
        cg_8_num: typing.Callable[[], T_Result],
        cp_1_num: typing.Callable[[], T_Result],
        cp_2_num: typing.Callable[[], T_Result],
        cp_3_num: typing.Callable[[], T_Result],
        cy_1_money: typing.Callable[[], T_Result],
        cy_2_money: typing.Callable[[], T_Result],
        cy_3_money: typing.Callable[[], T_Result],
        cy_4_money: typing.Callable[[], T_Result],
        cy_5_money: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ValueCode.C_01_MONEY:
            return c_01_money()
        if self is ValueCode.C_02_MONEY:
            return c_02_money()
        if self is ValueCode.C_04_MONEY:
            return c_04_money()
        if self is ValueCode.C_05_MONEY:
            return c_05_money()
        if self is ValueCode.C_06_MONEY:
            return c_06_money()
        if self is ValueCode.C_08_MONEY:
            return c_08_money()
        if self is ValueCode.C_09_MONEY:
            return c_09_money()
        if self is ValueCode.C_10_MONEY:
            return c_10_money()
        if self is ValueCode.C_11_MONEY:
            return c_11_money()
        if self is ValueCode.C_12_MONEY:
            return c_12_money()
        if self is ValueCode.C_13_MONEY:
            return c_13_money()
        if self is ValueCode.C_14_MONEY:
            return c_14_money()
        if self is ValueCode.C_15_MONEY:
            return c_15_money()
        if self is ValueCode.C_16_MONEY:
            return c_16_money()
        if self is ValueCode.C_21_MONEY:
            return c_21_money()
        if self is ValueCode.C_22_MONEY:
            return c_22_money()
        if self is ValueCode.C_23_MONEY:
            return c_23_money()
        if self is ValueCode.C_24_NUM:
            return c_24_num()
        if self is ValueCode.C_25_MONEY:
            return c_25_money()
        if self is ValueCode.C_26_MONEY:
            return c_26_money()
        if self is ValueCode.C_27_MONEY:
            return c_27_money()
        if self is ValueCode.C_28_MONEY:
            return c_28_money()
        if self is ValueCode.C_29_MONEY:
            return c_29_money()
        if self is ValueCode.C_30_MONEY:
            return c_30_money()
        if self is ValueCode.C_31_MONEY:
            return c_31_money()
        if self is ValueCode.C_32_NUM:
            return c_32_num()
        if self is ValueCode.C_33_MONEY:
            return c_33_money()
        if self is ValueCode.C_34_MONEY:
            return c_34_money()
        if self is ValueCode.C_35_MONEY:
            return c_35_money()
        if self is ValueCode.C_37_NUM:
            return c_37_num()
        if self is ValueCode.C_38_NUM:
            return c_38_num()
        if self is ValueCode.C_39_NUM:
            return c_39_num()
        if self is ValueCode.C_40_MONEY:
            return c_40_money()
        if self is ValueCode.C_41_MONEY:
            return c_41_money()
        if self is ValueCode.C_42_MONEY:
            return c_42_money()
        if self is ValueCode.C_43_MONEY:
            return c_43_money()
        if self is ValueCode.C_44_MONEY:
            return c_44_money()
        if self is ValueCode.C_45_NUM:
            return c_45_num()
        if self is ValueCode.C_46_NUM:
            return c_46_num()
        if self is ValueCode.C_47_MONEY:
            return c_47_money()
        if self is ValueCode.C_48_NUM:
            return c_48_num()
        if self is ValueCode.C_49_NUM:
            return c_49_num()
        if self is ValueCode.C_50_NUM:
            return c_50_num()
        if self is ValueCode.C_51_NUM:
            return c_51_num()
        if self is ValueCode.C_52_NUM:
            return c_52_num()
        if self is ValueCode.C_53_NUM:
            return c_53_num()
        if self is ValueCode.C_54_NUM:
            return c_54_num()
        if self is ValueCode.C_55_MONEY:
            return c_55_money()
        if self is ValueCode.C_56_NUM:
            return c_56_num()
        if self is ValueCode.C_57_NUM:
            return c_57_num()
        if self is ValueCode.C_58_NUM:
            return c_58_num()
        if self is ValueCode.C_59_NUM:
            return c_59_num()
        if self is ValueCode.C_60_NUM:
            return c_60_num()
        if self is ValueCode.C_61_NUM:
            return c_61_num()
        if self is ValueCode.C_66_MONEY:
            return c_66_money()
        if self is ValueCode.C_67_NUM:
            return c_67_num()
        if self is ValueCode.C_68_NUM:
            return c_68_num()
        if self is ValueCode.C_69_NUM:
            return c_69_num()
        if self is ValueCode.C_80_NUM:
            return c_80_num()
        if self is ValueCode.C_81_NUM:
            return c_81_num()
        if self is ValueCode.C_82_NUM:
            return c_82_num()
        if self is ValueCode.C_83_NUM:
            return c_83_num()
        if self is ValueCode.C_84_NUM:
            return c_84_num()
        if self is ValueCode.C_85_NUM:
            return c_85_num()
        if self is ValueCode.C_87_MONEY:
            return c_87_money()
        if self is ValueCode.C_89_MONEY:
            return c_89_money()
        if self is ValueCode.C_90_MONEY:
            return c_90_money()
        if self is ValueCode.C_91_MONEY:
            return c_91_money()
        if self is ValueCode.CA_0_NUM:
            return ca_0_num()
        if self is ValueCode.CA_1_MONEY:
            return ca_1_money()
        if self is ValueCode.CA_2_MONEY:
            return ca_2_money()
        if self is ValueCode.CA_3_MONEY:
            return ca_3_money()
        if self is ValueCode.CA_4_MONEY:
            return ca_4_money()
        if self is ValueCode.CA_5_MONEY:
            return ca_5_money()
        if self is ValueCode.CA_6_MONEY:
            return ca_6_money()
        if self is ValueCode.CA_7_MONEY:
            return ca_7_money()
        if self is ValueCode.CA_8_NUM:
            return ca_8_num()
        if self is ValueCode.CA_9_NUM:
            return ca_9_num()
        if self is ValueCode.CAA_MONEY:
            return caa_money()
        if self is ValueCode.CAB_MONEY:
            return cab_money()
        if self is ValueCode.CB_1_MONEY:
            return cb_1_money()
        if self is ValueCode.CB_2_MONEY:
            return cb_2_money()
        if self is ValueCode.CB_3_MONEY:
            return cb_3_money()
        if self is ValueCode.CB_7_MONEY:
            return cb_7_money()
        if self is ValueCode.CBA_MONEY:
            return cba_money()
        if self is ValueCode.CBB_MONEY:
            return cbb_money()
        if self is ValueCode.CC_1_MONEY:
            return cc_1_money()
        if self is ValueCode.CC_2_MONEY:
            return cc_2_money()
        if self is ValueCode.CC_3_MONEY:
            return cc_3_money()
        if self is ValueCode.CC_7_MONEY:
            return cc_7_money()
        if self is ValueCode.CCA_MONEY:
            return cca_money()
        if self is ValueCode.CCB_MONEY:
            return ccb_money()
        if self is ValueCode.CD_3_MONEY:
            return cd_3_money()
        if self is ValueCode.CD_4_NUM:
            return cd_4_num()
        if self is ValueCode.CD_5_NUM:
            return cd_5_num()
        if self is ValueCode.CD_6_NUM:
            return cd_6_num()
        if self is ValueCode.CFC_MONEY:
            return cfc_money()
        if self is ValueCode.CFD_MONEY:
            return cfd_money()
        if self is ValueCode.CG_8_NUM:
            return cg_8_num()
        if self is ValueCode.CP_1_NUM:
            return cp_1_num()
        if self is ValueCode.CP_2_NUM:
            return cp_2_num()
        if self is ValueCode.CP_3_NUM:
            return cp_3_num()
        if self is ValueCode.CY_1_MONEY:
            return cy_1_money()
        if self is ValueCode.CY_2_MONEY:
            return cy_2_money()
        if self is ValueCode.CY_3_MONEY:
            return cy_3_money()
        if self is ValueCode.CY_4_MONEY:
            return cy_4_money()
        if self is ValueCode.CY_5_MONEY:
            return cy_5_money()
        return _unknown_member(self._value_)
