# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .universal_service_identifier import UniversalServiceIdentifier


class Service(UniversalBaseModel):
    universal_service_identifier: typing.Optional[UniversalServiceIdentifier] = pydantic.Field(default=None)
    """
    Contains the code describing the activity type that is being scheduled.
    """

    start_timestamp: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
