# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .condition_code import ConditionCode
from .condition_information_code_qualifier import ConditionInformationCodeQualifier
from .health_care_code_information_new import HealthCareCodeInformationNew


class ConditionInformationNew(HealthCareCodeInformationNew):
    """
    This corresponds to the BG code qualifier value.
    """

    condition_code_qualifier: ConditionInformationCodeQualifier
    condition_code: ConditionCode

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
