# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ...commons.types.patient_relationship_to_insured_code_all import PatientRelationshipToInsuredCodeAll
from ...commons.types.street_address_short_zip_optional import StreetAddressShortZipOptional
from .individual_base_optional import IndividualBaseOptional


class SubscriberBaseOptional(IndividualBaseOptional):
    patient_relationship_to_subscriber_code: typing.Optional[PatientRelationshipToInsuredCodeAll] = None
    date_of_birth: typing.Optional[dt.date] = None
    address: typing.Optional[StreetAddressShortZipOptional] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
