# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .....commons.types.encounter_id import EncounterId
from .....users.resources.v_2.types.user_v_2 import UserV2
from .base_attachment import BaseAttachment
from .encounter_attachment_type import EncounterAttachmentType


class EncounterAttachment(BaseAttachment):
    encounter_id: EncounterId
    attachment_type: EncounterAttachmentType
    created_at: dt.datetime
    created_by: UserV2

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
